All Classes and Interfaces
Class
Description
The
AbstractActionEvent provides a base implementation for an
ActionEvent.The
AbstractEvent provides a base implementation for an
Event.Abstract implementation of an
EventMatcher type.
The
AbstractMetaDataActionEvent provides a base implementation for an
MetaDataActionEvent.The
AbstractMetaDataEvent provides a base implementation for an
MetaDataEvent.This abstract class provides functionality to implement default refcodes
Observable behavior.Matches the given action with the action stored in an event's metadata
(ACTION EQUAL WITH).
An
ActionEvent extends the Event and provides additional
means to provide an action via ActionAccessor.getAction() being of a generic type.Matches the given alias with the alias stored in an event's metadata (ALIAS
EQUAL WITH).
Catches all events, no matching is done (CATCH ALL).
Catches no events, no matching is done (CATCH NONE).
Matches the given channel with the channel stored in an event's metadata
(CHANNEL EQUAL WITH).
This interface typifies the
Matcher interface for the usage with
ActionEvent instances.Declarative syntactic sugar which may be statically imported in order to
allow declarative definitions for the
EventMatcher elements.The Meta-Data describes the event which a publisher posts via the event bus
to an event subscriber's event listener.
Builder to build
EventMetaData.Matches the given group with the group stored in an event's metadata (GROUP
EQUAL WITH).
An
MetaDataActionEvent provides Meta-Data describing the
ActionEvent in more detail and a source being the origin of the
MetaDataActionEvent.An
MetaDataEvent provides Meta-Data describing the
ActionEvent in more detail and a source being the origin of the
MetaDataEvent.This interface typifies the
Matcher interface for the usage with
MetaDataEvent instances.The
Observable interface can be implemented by any class which can be
observed by Observer instances (proposal) or any listener interface
(custom as of your needs).An
ObservableObserver is an observer, observing an observable.The listener of an event subscriber to be fed with events by a event
publisher.
This
ObserverDescriptor describes the Observer, i.e. in some
cases an Observer requires an EventMatcher which determines
which ActionEvent instances to pass to the Observer.Provides methods to manage all subscribed
Observer instances as a
whole and is intended as an extension of the Observable interface.A system publishing
ActionEvent instances (such as an event bus), may
implement this interface.Provides an accessor for a publisher's type property.
Provides a builder method for a publisher's type property returning the
builder for applying multiple build operations.
Provides a mutator for a publisher's type property.
Provides a publisher's type property.
Matches by event publisher type (EVENT PUBLISHER TYPE).
An
SubscribeEvent is published by an Observable when an
observer is being subscribed.Matches the given universal ID with the universal ID stored in an event's
metadata (UNIVERSAL ID EQUAL WITH).
An
UnsubscribeEvent is published by an Observable when an
observer is being unsubscribed.