Index

A C D E F G H I M O P S T U W _ 
All Classes and Interfaces|All Packages|Constant Field Values

A

AbstractActionEvent<A,SRC> - Class in org.refcodes.observer
The AbstractActionEvent provides a base implementation for an ActionEvent.
AbstractActionEvent(A, SRC) - Constructor for class org.refcodes.observer.AbstractActionEvent
Constructs an event with the given source.
AbstractActionEvent(SRC) - Constructor for class org.refcodes.observer.AbstractActionEvent
Constructs an event with the given source.
AbstractEvent<SRC> - Class in org.refcodes.observer
The AbstractEvent provides a base implementation for an Event.
AbstractEvent(SRC) - Constructor for class org.refcodes.observer.AbstractEvent
Constructs an event with the given source.
AbstractEventMatcher<E extends Event<?>> - Class in org.refcodes.observer
Abstract implementation of an EventMatcher type.
AbstractEventMatcher(String, String) - Constructor for class org.refcodes.observer.AbstractEventMatcher
Constructs the EventMatcher instance with the given alias (action) and description.
AbstractMetaDataActionEvent<A,EM extends EventMetaData,SRC> - Class in org.refcodes.observer
The AbstractMetaDataActionEvent provides a base implementation for an MetaDataActionEvent.
AbstractMetaDataActionEvent(A, EM, SRC) - Constructor for class org.refcodes.observer.AbstractMetaDataActionEvent
Constructs an event with the given Meta-Data.
AbstractMetaDataActionEvent(A, SRC) - Constructor for class org.refcodes.observer.AbstractMetaDataActionEvent
Constructs an event with the given Meta-Data.
AbstractMetaDataActionEvent(EM, SRC) - Constructor for class org.refcodes.observer.AbstractMetaDataActionEvent
Constructs an event with the given Meta-Data.
AbstractMetaDataActionEvent(SRC) - Constructor for class org.refcodes.observer.AbstractMetaDataActionEvent
Constructs an event with the given Meta-Data.
AbstractMetaDataActionEvent.AbstractMetaDataActionEventBuilder<A,EM extends EventMetaData,SRC,B extends AbstractMetaDataActionEvent.AbstractMetaDataActionEventBuilder<A,EM,SRC,B>> - Class in org.refcodes.observer
Implementation of the MetaDataAccessor.MetaDataBuilder interface for easily creating MetaDataActionEvent instances.
AbstractMetaDataActionEventBuilder(A, EM, SRC) - Constructor for class org.refcodes.observer.AbstractMetaDataActionEvent.AbstractMetaDataActionEventBuilder
Constructs an event with the given Meta-Data.
AbstractMetaDataActionEventBuilder(A, SRC) - Constructor for class org.refcodes.observer.AbstractMetaDataActionEvent.AbstractMetaDataActionEventBuilder
Constructs an event with the given Meta-Data.
AbstractMetaDataActionEventBuilder(EM, SRC) - Constructor for class org.refcodes.observer.AbstractMetaDataActionEvent.AbstractMetaDataActionEventBuilder
Constructs an event with the given Meta-Data.
AbstractMetaDataActionEventBuilder(SRC) - Constructor for class org.refcodes.observer.AbstractMetaDataActionEvent.AbstractMetaDataActionEventBuilder
Constructs an event with the given Meta-Data.
AbstractMetaDataEvent<EM extends EventMetaData,SRC> - Class in org.refcodes.observer
The AbstractMetaDataEvent provides a base implementation for an MetaDataEvent.
AbstractMetaDataEvent(EM, SRC) - Constructor for class org.refcodes.observer.AbstractMetaDataEvent
Constructs an event with the given Meta-Data.
AbstractMetaDataEvent(String, SRC) - Constructor for class org.refcodes.observer.AbstractMetaDataEvent
Constructs an event with the given Meta-Data.
AbstractMetaDataEvent(SRC) - Constructor for class org.refcodes.observer.AbstractMetaDataEvent
Constructs an event with the given Meta-Data.
AbstractObservable<O,EV> - Class in org.refcodes.observer
This abstract class provides functionality to implement default refcodes Observable behavior.
AbstractObservable() - Constructor for class org.refcodes.observer.AbstractObservable
Constructs the AbstractObservable with a default ExecutorService pool.
AbstractObservable(ExecutorService) - Constructor for class org.refcodes.observer.AbstractObservable
Constructs the AbstractObservable with a provided ExecutorService pool.
actionEqualWith(A) - Static method in class org.refcodes.observer.EventMatcherSugar
Factory method to create an "ACTION EQUAL WITH" matcher for the given action compared with the action stored in the EventMetaData.
ActionEqualWithEventMatcher<E extends MetaDataActionEvent<?,?,?>> - Class in org.refcodes.observer
Matches the given action with the action stored in an event's meta data (ACTION EQUAL WITH).
ActionEqualWithEventMatcher(A) - Constructor for class org.refcodes.observer.ActionEqualWithEventMatcher
Instantiates a new action equal with matcher.
ActionEvent<A,SRC> - Interface in org.refcodes.observer
An ActionEvent extends the Event and provides additional means to provide an action via ActionAccessor.getAction() being of a generic type.
ALIAS - Static variable in class org.refcodes.observer.ActionEqualWithEventMatcher
 
ALIAS - Static variable in class org.refcodes.observer.AliasEqualWithEventMatcher
 
ALIAS - Static variable in class org.refcodes.observer.CatchAllEventMatcher
 
ALIAS - Static variable in class org.refcodes.observer.CatchNoneEventMatcher
 
ALIAS - Static variable in class org.refcodes.observer.ChannelEqualWithEventMatcher
 
ALIAS - Static variable in class org.refcodes.observer.GroupEqualWithEventMatcher
 
ALIAS - Static variable in class org.refcodes.observer.PublisherIsAssignableFromMatcher
 
ALIAS - Static variable in class org.refcodes.observer.UniversalIdEqualWithEventMatcher
 
aliasEqualWith(String) - Static method in class org.refcodes.observer.EventMatcherSugar
Factory method to create an "ALIAS EQUAL WITH" matcher for the given alias compared with the alias stored in the EventMetaData.
AliasEqualWithEventMatcher<E extends MetaDataEvent<?,?>> - Class in org.refcodes.observer
Matches the given alias with the alias stored in an event's meta data (ALIAS EQUAL WITH).
AliasEqualWithEventMatcher(String) - Constructor for class org.refcodes.observer.AliasEqualWithEventMatcher
Instantiates a new alias equal with matcher impl.
and(EventMatcher<E>...) - Static method in class org.refcodes.observer.EventMatcherSugar
Factory method to create an "AND" matcher for the given matchers.

C

catchAll() - Static method in class org.refcodes.observer.EventMatcherSugar
Catches all events, no matching is done.
CatchAllEventMatcher<E extends MetaDataEvent<?,?>> - Class in org.refcodes.observer
Catches all events, no matching is done (CATCH ALL).
CatchAllEventMatcher() - Constructor for class org.refcodes.observer.CatchAllEventMatcher
Constructs the "catch all" EventMatcher instance.
catchNone() - Static method in class org.refcodes.observer.EventMatcherSugar
Catches no event, no matching is done.
CatchNoneEventMatcher<E extends MetaDataEvent<?,?>> - Class in org.refcodes.observer
Catches no events, no matching is done (CATCH NONE).
CatchNoneEventMatcher() - Constructor for class org.refcodes.observer.CatchNoneEventMatcher
Constructs the "catch all" EventMatcher instance.
channelEqualWith(String) - Static method in class org.refcodes.observer.EventMatcherSugar
Factory method to create an "CHANNEL EQUAL WITH" matcher for the given channel compared with the channel stored in the EventMetaData.
ChannelEqualWithEventMatcher<E extends MetaDataEvent<?,?>> - Class in org.refcodes.observer
Matches the given channel with the channel stored in an event's meta data (CHANNEL EQUAL WITH).
ChannelEqualWithEventMatcher(String) - Constructor for class org.refcodes.observer.ChannelEqualWithEventMatcher
Instantiates a new channel equal with matcher impl.
clear() - Method in class org.refcodes.observer.AbstractObservable
Clears all observers from this AbstractObservable.

D

disableObservers() - Method in interface org.refcodes.observer.Observers
Disables all observables.
dispose() - Method in class org.refcodes.observer.AbstractObservable
doHandleEventListenerException(Exception, O, EV, ExecutionStrategy) - Method in class org.refcodes.observer.AbstractObservable
This hook method allows you to handle any exceptions being thrown by an event listener whilst invoking a given event.

E

enableObservers() - Method in interface org.refcodes.observer.Observers
Enables all observables.
Event<SRC> - Interface in org.refcodes.observer
An Event is published by an Observable and is consumed by zero to many Observer instances.
EventMatcher<E extends Event<?>> - Interface in org.refcodes.observer
This interface typifies the Matcher interface for the usage with ActionEvent instances.
EventMatcherSugar - Class in org.refcodes.observer
Declarative syntactic sugar which may be statically imported in order to allow declarative definitions for the EventMatcher elements.
EventMatcherSugar() - Constructor for class org.refcodes.observer.EventMatcherSugar
 
EventMetaData - Class in org.refcodes.observer
The Meta-Data describes the event which a publisher posts via the event bus to an event subscriber's event listener.
EventMetaData() - Constructor for class org.refcodes.observer.EventMetaData
Constructs the EventMetaData with no properties set except the Universal-TID.
EventMetaData(Class<?>) - Constructor for class org.refcodes.observer.EventMetaData
Constructs the EventMetaData with the given properties.
EventMetaData(String) - Constructor for class org.refcodes.observer.EventMetaData
Constructs the EventMetaData with the given properties.
EventMetaData(String, Class<?>) - Constructor for class org.refcodes.observer.EventMetaData
Constructs the EventMetaData with the given properties.
EventMetaData(String, String) - Constructor for class org.refcodes.observer.EventMetaData
Constructs the EventMetaData with the given properties.
EventMetaData(String, String, String) - Constructor for class org.refcodes.observer.EventMetaData
Constructs the EventMetaData with the given properties.
EventMetaData(String, String, String, Class<?>) - Constructor for class org.refcodes.observer.EventMetaData
Constructs the EventMetaData with the given properties.
EventMetaData(String, String, String, String, Class<?>) - Constructor for class org.refcodes.observer.EventMetaData
Constructs the EventMetaData with the given properties.
EventMetaData(EventMetaData) - Constructor for class org.refcodes.observer.EventMetaData
Constructs the EventMetaData with the properties provided by the given EventMetaData instance.
EventMetaDataBuilder - Class in org.refcodes.observer
The EventMetaDataBuilder is the builder class counterpart of the EventMetaData class.
EventMetaDataBuilder() - Constructor for class org.refcodes.observer.EventMetaDataBuilder
Constructs the EventMetaData with no properties set except the Universal-TID.
EventMetaDataBuilder(Class<?>) - Constructor for class org.refcodes.observer.EventMetaDataBuilder
Constructs the EventMetaData with the given properties.
EventMetaDataBuilder(String) - Constructor for class org.refcodes.observer.EventMetaDataBuilder
Constructs the EventMetaData with the given properties.
EventMetaDataBuilder(String, String) - Constructor for class org.refcodes.observer.EventMetaDataBuilder
Constructs the EventMetaData with the given properties.
EventMetaDataBuilder(String, String, String) - Constructor for class org.refcodes.observer.EventMetaDataBuilder
Constructs the EventMetaData with the given properties.
EventMetaDataBuilder(String, String, String, Class<?>) - Constructor for class org.refcodes.observer.EventMetaDataBuilder
Constructs the EventMetaData with the given properties.
EventMetaDataBuilder(String, String, String, String, Class<?>) - Constructor for class org.refcodes.observer.EventMetaDataBuilder
Constructs the EventMetaData with the given properties.
EventMetaDataBuilder(EventMetaData) - Constructor for class org.refcodes.observer.EventMetaDataBuilder
Constructs the EventMetaData with the properties provided by the given EventMetaData instance.

F

fireEvent(EV, ExecutionStrategy) - Method in class org.refcodes.observer.AbstractObservable
To be used by the implementing class when firing an event to it's listeners.
fireEvent(EV, O, ExecutionStrategy) - Method in class org.refcodes.observer.AbstractObservable
This hook method is to be implemented by the implementing class.

G

getAction() - Method in class org.refcodes.observer.AbstractActionEvent
getAlias() - Method in class org.refcodes.observer.AbstractEventMatcher
getAlias() - Method in class org.refcodes.observer.EventMetaData
getAlias() - Method in class org.refcodes.observer.EventMetaDataBuilder
getChannel() - Method in class org.refcodes.observer.EventMetaData
getChannel() - Method in class org.refcodes.observer.EventMetaDataBuilder
getEventMatcher() - Method in class org.refcodes.observer.ObserverDescriptor
Returns the EventMatcher associated with the given Observer.
getGroup() - Method in class org.refcodes.observer.EventMetaData
getGroup() - Method in class org.refcodes.observer.EventMetaDataBuilder
getMetaData() - Method in class org.refcodes.observer.AbstractMetaDataActionEvent
getMetaData() - Method in class org.refcodes.observer.AbstractMetaDataEvent
getObserver() - Method in class org.refcodes.observer.ObserverDescriptor
Returns the Observer associated with the given EventMatcher.
getPublisherType() - Method in class org.refcodes.observer.EventMetaData
The least common denominator in event Meta-Data is the type of the publisher which gives a hint on the source of the event.
getPublisherType() - Method in class org.refcodes.observer.EventMetaDataBuilder
The least common denominator in event Meta-Data is the type of the publisher which gives a hint on the source of the event.
getSource() - Method in class org.refcodes.observer.AbstractEvent
getThreadPriority() - Method in class org.refcodes.observer.AbstractObservable
In case of ExecutionStrategy.PARALLEL or ExecutionStrategy.JOIN, the threads' priority is defined by this attribute.
getUniversalId() - Method in class org.refcodes.observer.EventMetaData
getUniversalId() - Method in class org.refcodes.observer.EventMetaDataBuilder
groupEqualWith(String) - Static method in class org.refcodes.observer.EventMatcherSugar
Factory method to create an "GROUP EQUAL WITH" matcher for the given group compared with the group stored in the EventMetaData.
GroupEqualWithEventMatcher<E extends MetaDataEvent<?,?>> - Class in org.refcodes.observer
Matches the given group with the group stored in an event's meta data (GROUP EQUAL WITH).
GroupEqualWithEventMatcher(String) - Constructor for class org.refcodes.observer.GroupEqualWithEventMatcher
Instantiates a new group equal with matcher impl.

H

hasObserver(O) - Method in class org.refcodes.observer.AbstractObservable
Tests whether the given observer (event listener) has been added to this Observable.
hasObserver(O) - Method in interface org.refcodes.observer.Observable
Tests whether the given observer (event listener) has been added to this Observable.

I

isAssignableFrom(Class<?>) - Static method in class org.refcodes.observer.EventMatcherSugar
Factory method to create an event matcher by event type.
isEmpty() - Method in class org.refcodes.observer.AbstractObservable
Determines whether there are observers being registered.
isMatching(E) - Method in class org.refcodes.observer.ActionEqualWithEventMatcher
Tests whether the given ActionEvent is matching the Matcher's criteria.
isMatching(E) - Method in class org.refcodes.observer.AliasEqualWithEventMatcher
Tests whether the given ActionEvent is matching the Matcher's criteria.
isMatching(E) - Method in class org.refcodes.observer.CatchAllEventMatcher
Tests whether the given ActionEvent is matching the Matcher's criteria.
isMatching(E) - Method in class org.refcodes.observer.CatchNoneEventMatcher
Tests whether the given ActionEvent is matching the Matcher's criteria.
isMatching(E) - Method in class org.refcodes.observer.ChannelEqualWithEventMatcher
Tests whether the given ActionEvent is matching the Matcher's criteria.
isMatching(E) - Method in interface org.refcodes.observer.EventMatcher
Tests whether the given ActionEvent is matching the Matcher's criteria.
isMatching(E) - Method in class org.refcodes.observer.GroupEqualWithEventMatcher
Tests whether the given ActionEvent is matching the Matcher's criteria.
isMatching(E) - Method in interface org.refcodes.observer.MetaDataEventMatcher
Tests whether the given event is matching the mathcer's criteria.
isMatching(E) - Method in class org.refcodes.observer.PublisherIsAssignableFromMatcher
Tests whether the given ActionEvent is matching the Matcher's criteria.
isMatching(E) - Method in class org.refcodes.observer.UniversalIdEqualWithEventMatcher
Tests whether the given ActionEvent is matching the Matcher's criteria.
isObserversActive() - Method in class org.refcodes.observer.AbstractObservable
Checks if is observers active.
isObserversActive() - Method in interface org.refcodes.observer.Observers
Returns true when all Observer instances are theoretically active (the instance may also decide by itself), else false.

M

MetaDataActionEvent<A,EM extends EventMetaData,SRC> - Interface in org.refcodes.observer
An MetaDataActionEvent provides Meta-Data describing the ActionEvent in more detail and a source being the origin of the MetaDataActionEvent.
MetaDataActionEventBuilder<A,EM extends EventMetaData,SRC,B extends MetaDataActionEventBuilder<A,EM,SRC,B>> - Interface in org.refcodes.observer
Builder extension for the MetaDataActionEvent type.
MetaDataEvent<EM extends EventMetaData,SRC> - Interface in org.refcodes.observer
An MetaDataEvent provides Meta-Data describing the ActionEvent in more detail and a source being the origin of the MetaDataEvent.
MetaDataEventBuilder<A,EM extends EventMetaData,SRC,B extends MetaDataEventBuilder<A,EM,SRC,B>> - Interface in org.refcodes.observer
Builder extension for the MetaDataActionEvent type.
MetaDataEventMatcher<E extends MetaDataEvent<?,?>> - Interface in org.refcodes.observer
This interface typifies the Matcher interface for the usage with MetaDataEvent instances.

O

Observable<O> - Interface in org.refcodes.observer
The Observable interface can be implemented by any class which can be observed by Observer instances (proposal) or any listener interface (custom as of your needs).
ObservableObserver<O extends Observable<?>> - Interface in org.refcodes.observer
An ObservableObserver is an observer, observing an observable.
Observer<E extends Event<?>> - Interface in org.refcodes.observer
The listener of an event subscriber to be fed with events by a event publisher.
ObserverDescriptor<E extends Event<?>,O extends Observer<E>,EM extends EventMatcher<E>> - Class in org.refcodes.observer
This ObserverDescriptor describes the Observer, i.e. in some cases an Observer requires an EventMatcher which determines which ActionEvent instances to pass to the Observer.
ObserverDescriptor(O, EM) - Constructor for class org.refcodes.observer.ObserverDescriptor
Constructs the event listener descriptor with the given event listener and the given event matcher.
observers() - Method in class org.refcodes.observer.AbstractObservable
Observers.
observers() - Method in interface org.refcodes.observer.Observers
Returns an Iterator with the registered observers.
Observers<O,B extends Observers<O,B>> - Interface in org.refcodes.observer
Provides methods to manage all subscribed Observer instances as a whole and is intended as an extension of the Observable interface.
onEvent(E) - Method in interface org.refcodes.observer.Observer
The listener implementing this interface is notified of an event via this method.
onEvent(E) - Method in class org.refcodes.observer.ObserverDescriptor
The listener implementing this interface is notified of an event via this method.
onSubscribe(SubscribeEvent<O>) - Method in interface org.refcodes.observer.ObservableObserver
This method is called when information about an Observable which was previously requested using an asynchronous interface becomes available.
onUnsubscribe(UnsubscribeEvent<O>) - Method in interface org.refcodes.observer.ObservableObserver
This method is called when information about an Observable which was previously requested using an asynchronous interface becomes available.
or(EventMatcher<E>...) - Static method in class org.refcodes.observer.EventMatcherSugar
Factory method to create an "OR" matcher for the given matchers.
org.refcodes.observer - module org.refcodes.observer
 
org.refcodes.observer - package org.refcodes.observer
This package provides types supporting the Observable-Pattern.

P

Publisher<E extends Event<?>> - Interface in org.refcodes.observer
A system publishing ActionEvent instances (such as an event bus), may implement this interface.
publisherIsAssignableFrom(Class<? extends PT>) - Static method in class org.refcodes.observer.EventMatcherSugar
Factory method to create an event matcher by event publisher type.
PublisherIsAssignableFromMatcher<E extends MetaDataEvent<?,?>,PT> - Class in org.refcodes.observer
Matches by event publisher type (EVENT PUBLISHER TYPE).
PublisherIsAssignableFromMatcher(Class<? extends PT>) - Constructor for class org.refcodes.observer.PublisherIsAssignableFromMatcher
Instantiates a new publisher is assignable from matcher impl.
publishEvent(E) - Method in interface org.refcodes.observer.Publisher
The listener implementing this interface is notified of an event via this method.

S

setAction(A) - Method in class org.refcodes.observer.AbstractMetaDataActionEvent.AbstractMetaDataActionEventBuilder
setAlias(String) - Method in class org.refcodes.observer.EventMetaDataBuilder
setChannel(String) - Method in class org.refcodes.observer.EventMetaDataBuilder
setGroup(String) - Method in class org.refcodes.observer.EventMetaDataBuilder
setObserversActive(boolean) - Method in class org.refcodes.observer.AbstractObservable
Sets the observers active.
setObserversActive(boolean) - Method in interface org.refcodes.observer.Observers
Enables or disables all Observer instances.
setPublisherType(Class<?>) - Method in class org.refcodes.observer.EventMetaDataBuilder
The least common denominator in event Meta-Data is the type of the publisher which gives a hint on the source of the event.
setPublisherType(Class<?>) - Method in interface org.refcodes.observer.MetaDataEventBuilder
Sets the publisher's type.
setThreadPriority(int) - Method in class org.refcodes.observer.AbstractObservable
In case of ExecutionStrategy.PARALLEL or ExecutionStrategy.JOIN, the threads' priority is defined by this attribute.
setUniversalId(String) - Method in class org.refcodes.observer.EventMetaDataBuilder
size() - Method in class org.refcodes.observer.AbstractObservable
Determines the number of observers being registered.
SubscribeEvent<SRC> - Class in org.refcodes.observer
An SubscribeEvent is published by an Observable when an observer is being subscribed.
SubscribeEvent(SRC) - Constructor for class org.refcodes.observer.SubscribeEvent
Instantiates a new subscribe event.
subscribeObserver(O) - Method in class org.refcodes.observer.AbstractObservable
Adds the given observer (event listener).
subscribeObserver(O) - Method in interface org.refcodes.observer.Observable
Adds the given observer (event listener).

T

toSchema() - Method in class org.refcodes.observer.AbstractEventMatcher
toSchema() - Method in class org.refcodes.observer.ActionEqualWithEventMatcher
toSchema() - Method in class org.refcodes.observer.AliasEqualWithEventMatcher
toSchema() - Method in class org.refcodes.observer.ChannelEqualWithEventMatcher
toSchema() - Method in class org.refcodes.observer.GroupEqualWithEventMatcher
toSchema() - Method in class org.refcodes.observer.PublisherIsAssignableFromMatcher
toSchema() - Method in class org.refcodes.observer.UniversalIdEqualWithEventMatcher
toString() - Method in class org.refcodes.observer.AbstractMetaDataActionEvent
toString() - Method in class org.refcodes.observer.AbstractMetaDataEvent
toString() - Method in class org.refcodes.observer.EventMetaData

U

universalIdEqualWith(String) - Static method in class org.refcodes.observer.EventMatcherSugar
Factory method to create an "UNIVERSAL ID EQUAL WITH" matcher for the given UID compared with the UID stored in the EventMetaData.
UniversalIdEqualWithEventMatcher<E extends MetaDataEvent<?,?>> - Class in org.refcodes.observer
Matches the given universal ID with the universal ID stored in an event's meta data (UNIVERSAL ID EQUAL WITH).
UniversalIdEqualWithEventMatcher(String) - Constructor for class org.refcodes.observer.UniversalIdEqualWithEventMatcher
Instantiates a new Universal-ID equal with matcher impl.
UnsubscribeEvent<SRC> - Class in org.refcodes.observer
An UnsubscribeEvent is published by an Observable when an observer is being unsubscribed.
UnsubscribeEvent(SRC) - Constructor for class org.refcodes.observer.UnsubscribeEvent
Instantiates a new unsubscribe event.
unsubscribeObserver(O) - Method in class org.refcodes.observer.AbstractObservable
Removes the observer (event listener).
unsubscribeObserver(O) - Method in interface org.refcodes.observer.Observable
Removes the observer (event listener).

W

withAction(A) - Method in class org.refcodes.observer.AbstractMetaDataActionEvent.AbstractMetaDataActionEventBuilder
withAction(A) - Method in interface org.refcodes.observer.MetaDataActionEventBuilder
withAlias(String) - Method in class org.refcodes.observer.EventMetaDataBuilder
withAlias(String) - Method in interface org.refcodes.observer.MetaDataEventBuilder
withChannel(String) - Method in class org.refcodes.observer.EventMetaDataBuilder
withChannel(String) - Method in interface org.refcodes.observer.MetaDataEventBuilder
withDisableObservers() - Method in interface org.refcodes.observer.Observers
Builder method for the Observers.disableObservers() operation.
withEnableObservers() - Method in interface org.refcodes.observer.Observers
Builder method for the Observers.enableObservers() operation.
withGroup(String) - Method in class org.refcodes.observer.EventMetaDataBuilder
withGroup(String) - Method in interface org.refcodes.observer.MetaDataEventBuilder
withMetaData(EM) - Method in class org.refcodes.observer.AbstractMetaDataActionEvent.AbstractMetaDataActionEventBuilder
withMetaData(EM) - Method in interface org.refcodes.observer.MetaDataEventBuilder
withObserversActive(boolean) - Method in interface org.refcodes.observer.Observers
Builder method for the Observers.setObserversActive(boolean) operation.
withPublisherType(Class<?>) - Method in class org.refcodes.observer.EventMetaDataBuilder
The least common denominator in event Meta-Data is the type of the publisher which gives a hint on the source of the event.
withPublisherType(Class<?>) - Method in interface org.refcodes.observer.MetaDataEventBuilder
Sets the publisher for the publisher property.
withUniversalId(String) - Method in class org.refcodes.observer.EventMetaDataBuilder
withUniversalId(String) - Method in interface org.refcodes.observer.MetaDataEventBuilder

_

_action - Variable in class org.refcodes.observer.AbstractActionEvent
 
_alias - Variable in class org.refcodes.observer.EventMetaData
 
_channel - Variable in class org.refcodes.observer.EventMetaData
 
_eventMetaData - Variable in class org.refcodes.observer.AbstractMetaDataActionEvent
 
_eventMetaData - Variable in class org.refcodes.observer.AbstractMetaDataEvent
 
_group - Variable in class org.refcodes.observer.EventMetaData
 
_publisherType - Variable in class org.refcodes.observer.EventMetaData
 
_uid - Variable in class org.refcodes.observer.EventMetaData
 
A C D E F G H I M O P S T U W _ 
All Classes and Interfaces|All Packages|Constant Field Values