Class AbstractMetaDataActionEvent<A,EM extends EventMetaData,SRC>

java.lang.Object
org.refcodes.observer.AbstractEvent<SRC>
org.refcodes.observer.AbstractActionEvent<A,SRC>
org.refcodes.observer.AbstractMetaDataActionEvent<A,EM,SRC>
Type Parameters:
A - The type of the action stored in the event.
EM - The type of the EventMetaData
SRC - The type of the source in question.
All Implemented Interfaces:
org.refcodes.mixin.ActionAccessor<A>, org.refcodes.mixin.MetaDataAccessor<EM>, org.refcodes.mixin.SourceAccessor<SRC>, ActionEvent<A,SRC>, Event<SRC>, MetaDataActionEvent<A,EM,SRC>, MetaDataEvent<EM,SRC>

public abstract class AbstractMetaDataActionEvent<A,EM extends EventMetaData,SRC> extends AbstractActionEvent<A,SRC> implements MetaDataActionEvent<A,EM,SRC>
The AbstractMetaDataActionEvent provides a base implementation for an MetaDataActionEvent. In order to distinguish AbstractMetaDataActionEvent instances from each other, you may create an actions enumeration, enumerating the various event actions you support. Pass the actual action you intend to notify upon to the according constructor, as an Observer you may use the declarative method EventMatcherSugar.actionEqualWith(Object) to test whether your action was notified (or a simple switch case statement).