Interface ActionEvent<A,SRC>

Type Parameters:
A - The type of the action stored in the event.
SRC - The type of the source in question.
All Superinterfaces:
ActionAccessor<A>, Event<SRC>, SourceAccessor<SRC>
All Known Subinterfaces:
MetaDataActionEvent<A,EM,SRC>
All Known Implementing Classes:
AbstractActionEvent, AbstractMetaDataActionEvent

public interface ActionEvent<A,SRC> extends Event<SRC>, ActionAccessor<A>
An ActionEvent extends the Event and provides additional means to provide an action via ActionAccessor.getAction() being of a generic type. The action can be used to easily describe the intend of the event without sub-classing an ActionEvent enabled {GenericEvent} class for each intend.