Interface Event<SRC>

Type Parameters:
SRC - The type of the source in question.
All Superinterfaces:
SourceAccessor<SRC>
All Known Subinterfaces:
ActionEvent<A,SRC>, MetaDataActionEvent<A,EM,SRC>, MetaDataEvent<EM,SRC>
All Known Implementing Classes:
AbstractActionEvent, AbstractEvent, AbstractMetaDataActionEvent, AbstractMetaDataEvent, SubscribeEvent, UnsubscribeEvent

public interface Event<SRC> extends SourceAccessor<SRC>
An Event is published by an Observable and is consumed by zero to many Observer instances. The Event object describes what the Observable is publishing. An Event provides a source being the origin of the Event.