Interface EventMatcher<E extends Event<?>>
- Type Parameters:
E- The matchee type.
- All Superinterfaces:
AliasAccessor, Diagnosable, Matchable<E>, Matcher<E>, Predicate<E>, Schemable<DiagnosticOptions>
- All Known Subinterfaces:
MetaDataEventMatcher<E>
- All Known Implementing Classes:
AbstractEventMatcher, ActionEqualWithEventMatcher, AliasEqualWithEventMatcher, CatchAllEventMatcher, CatchNoneEventMatcher, ChannelEqualWithEventMatcher, GroupEqualWithEventMatcher, PublisherTypeOfEventMatcher, UniversalIdEqualWithEventMatcher
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
This interface typifies the
Matcher interface for the usage with
ActionEvent instances. An EventMatcher most commonly uses the
EventMetaData (as defined with the MetaDataEvent) in order to
determine whether an ActionEvent matches EventMetaData
properties or not.-
Nested Class Summary
Nested classes/interfaces inherited from interface AliasAccessor
AliasAccessor.AliasBuilder<B>, AliasAccessor.AliasMutator, AliasAccessor.AliasProperty -
Method Summary
Modifier and TypeMethodDescriptionbooleanTests whether the givenActionEventis matching theMatcher's criteria.
-
Method Details
-
test
Tests whether the givenActionEventis matching theMatcher's criteria.
-