Class EventMetaData

java.lang.Object
org.refcodes.observer.EventMetaData
All Implemented Interfaces:
AliasAccessor, ChannelAccessor, GroupAccessor, UniversalIdAccessor, PublisherTypeAccessor

The Meta-Data describes the event which a publisher posts via the event bus to an event subscriber's event listener. The Meta-Data is the criteria most commonly used by an event matcher in order to identify an loosely coupled event.