java.lang.Object
org.refcodes.observer.EventMetaData
org.refcodes.observer.EventMetaDataBuilder
- All Implemented Interfaces:
org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.AliasAccessor.AliasBuilder<EventMetaDataBuilder>,org.refcodes.mixin.AliasAccessor.AliasMutator,org.refcodes.mixin.AliasAccessor.AliasProperty,org.refcodes.mixin.ChannelAccessor,org.refcodes.mixin.ChannelAccessor.ChannelBuilder<EventMetaDataBuilder>,org.refcodes.mixin.ChannelAccessor.ChannelMutator,org.refcodes.mixin.ChannelAccessor.ChannelProperty,org.refcodes.mixin.GroupAccessor,org.refcodes.mixin.GroupAccessor.GroupBuilder<EventMetaDataBuilder>,org.refcodes.mixin.GroupAccessor.GroupMutator,org.refcodes.mixin.GroupAccessor.GroupProperty,org.refcodes.mixin.UniversalIdAccessor,org.refcodes.mixin.UniversalIdAccessor.UniversalIdBuilder<EventMetaDataBuilder>,org.refcodes.mixin.UniversalIdAccessor.UniversalIdMutator,org.refcodes.mixin.UniversalIdAccessor.UniversalIdProperty
public class EventMetaDataBuilder
extends EventMetaData
implements org.refcodes.mixin.UniversalIdAccessor.UniversalIdProperty, org.refcodes.mixin.UniversalIdAccessor.UniversalIdBuilder<EventMetaDataBuilder>, org.refcodes.mixin.AliasAccessor.AliasProperty, org.refcodes.mixin.AliasAccessor.AliasBuilder<EventMetaDataBuilder>, org.refcodes.mixin.GroupAccessor.GroupProperty, org.refcodes.mixin.GroupAccessor.GroupBuilder<EventMetaDataBuilder>, org.refcodes.mixin.ChannelAccessor.ChannelProperty, org.refcodes.mixin.ChannelAccessor.ChannelBuilder<EventMetaDataBuilder>
The
EventMetaDataBuilder is the builder class counterpart of the
EventMetaData class.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.ChannelAccessor
org.refcodes.mixin.ChannelAccessor.ChannelBuilder<B extends org.refcodes.mixin.ChannelAccessor.ChannelBuilder<B>>, org.refcodes.mixin.ChannelAccessor.ChannelMutator, org.refcodes.mixin.ChannelAccessor.ChannelPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.GroupAccessor
org.refcodes.mixin.GroupAccessor.GroupBuilder<B extends org.refcodes.mixin.GroupAccessor.GroupBuilder<B>>, org.refcodes.mixin.GroupAccessor.GroupMutator, org.refcodes.mixin.GroupAccessor.GroupPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.UniversalIdAccessor
org.refcodes.mixin.UniversalIdAccessor.UniversalIdBuilder<B extends org.refcodes.mixin.UniversalIdAccessor.UniversalIdBuilder<B>>, org.refcodes.mixin.UniversalIdAccessor.UniversalIdMutator, org.refcodes.mixin.UniversalIdAccessor.UniversalIdProperty -
Field Summary
Fields inherited from class org.refcodes.observer.EventMetaData
_alias, _channel, _group, _publisherType, _uid -
Constructor Summary
ConstructorsConstructorDescriptionConstructs theEventMetaDatawith no properties set except the Universal-TID.EventMetaDataBuilder(Class<?> aPublisherType) Constructs theEventMetaDatawith the given properties.EventMetaDataBuilder(String aChannel) Constructs theEventMetaDatawith the given properties.EventMetaDataBuilder(String aAlias, String aGroup) Constructs theEventMetaDatawith the given properties.EventMetaDataBuilder(String aAlias, String aGroup, String aChannel) Constructs theEventMetaDatawith the given properties.EventMetaDataBuilder(String aAlias, String aGroup, String aChannel, Class<?> aPublisherType) Constructs theEventMetaDatawith the given properties.EventMetaDataBuilder(String aAlias, String aGroup, String aChannel, String aUid, Class<?> aPublisherType) Constructs theEventMetaDatawith the given properties.EventMetaDataBuilder(EventMetaData aMetaData) Constructs theEventMetaDatawith the properties provided by the givenEventMetaDatainstance. -
Method Summary
Modifier and TypeMethodDescriptiongetAlias()getGroup()Class<?>The least common denominator in event Meta-Data is the type of the publisher which gives a hint on the source of the event.voidvoidsetChannel(String aChannel) voidvoidsetPublisherType(Class<?> aPublisherType) The least common denominator in event Meta-Data is the type of the publisher which gives a hint on the source of the event.voidsetUniversalId(String aUid) withChannel(String aChannel) withPublisherType(Class<?> aPublisherType) The least common denominator in event Meta-Data is the type of the publisher which gives a hint on the source of the event.withUniversalId(String aUid) Methods inherited from class org.refcodes.observer.EventMetaData
toStringMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.mixin.AliasAccessor.AliasProperty
letAliasMethods inherited from interface org.refcodes.mixin.ChannelAccessor.ChannelProperty
letChannelMethods inherited from interface org.refcodes.mixin.GroupAccessor.GroupProperty
letGroupMethods inherited from interface org.refcodes.mixin.UniversalIdAccessor.UniversalIdProperty
letUniversalId
-
Constructor Details
-
EventMetaDataBuilder
public EventMetaDataBuilder()Constructs theEventMetaDatawith no properties set except the Universal-TID. -
EventMetaDataBuilder
Constructs theEventMetaDatawith the given properties.- Parameters:
aPublisherType- The type of the publisher.
-
EventMetaDataBuilder
Constructs theEventMetaDatawith the properties provided by the givenEventMetaDatainstance.- Parameters:
aMetaData- TheEventMetaDatainstance from which to get the properties.
-
EventMetaDataBuilder
Constructs theEventMetaDatawith the given properties.- Parameters:
aChannel- The channel for theEventMetaData.
-
EventMetaDataBuilder
Constructs theEventMetaDatawith the given properties.- Parameters:
aAlias- The alias for theEventMetaData.aGroup- The group for theEventMetaData.
-
EventMetaDataBuilder
Constructs theEventMetaDatawith the given properties.- Parameters:
aAlias- The alias for theEventMetaData.aGroup- The group for theEventMetaData.aChannel- The channel for theEventMetaData.
-
EventMetaDataBuilder
Constructs theEventMetaDatawith the given properties.- Parameters:
aAlias- The alias for theEventMetaData.aGroup- The group for theEventMetaData.aChannel- The channel for theEventMetaData.aPublisherType- The name for theEventMetaData.
-
EventMetaDataBuilder
public EventMetaDataBuilder(String aAlias, String aGroup, String aChannel, String aUid, Class<?> aPublisherType) Constructs theEventMetaDatawith the given properties.- Parameters:
aAlias- The alias for theEventMetaData.aGroup- The group for theEventMetaData.aChannel- The channel for theEventMetaData.aUid- The Universal-TID for theEventMetaData.aPublisherType- The name for theEventMetaData.
-
-
Method Details
-
getAlias
- Specified by:
getAliasin interfaceorg.refcodes.mixin.AliasAccessor- Overrides:
getAliasin classEventMetaData
-
getChannel
- Specified by:
getChannelin interfaceorg.refcodes.mixin.ChannelAccessor- Overrides:
getChannelin classEventMetaData
-
getGroup
- Specified by:
getGroupin interfaceorg.refcodes.mixin.GroupAccessor- Overrides:
getGroupin classEventMetaData
-
getPublisherType
The least common denominator in event Meta-Data is the type of the publisher which gives a hint on the source of the event.- Overrides:
getPublisherTypein classEventMetaData- Returns:
- The type of the publisher who published the event.
-
getUniversalId
- Specified by:
getUniversalIdin interfaceorg.refcodes.mixin.UniversalIdAccessor- Overrides:
getUniversalIdin classEventMetaData
-
setAlias
- Specified by:
setAliasin interfaceorg.refcodes.mixin.AliasAccessor.AliasMutator
-
setChannel
- Specified by:
setChannelin interfaceorg.refcodes.mixin.ChannelAccessor.ChannelMutator
-
setGroup
- Specified by:
setGroupin interfaceorg.refcodes.mixin.GroupAccessor.GroupMutator
-
setPublisherType
The least common denominator in event Meta-Data is the type of the publisher which gives a hint on the source of the event.- Parameters:
aPublisherType- The type of the publisher who published the event.
-
setUniversalId
- Specified by:
setUniversalIdin interfaceorg.refcodes.mixin.UniversalIdAccessor.UniversalIdMutator
-
withAlias
- Specified by:
withAliasin interfaceorg.refcodes.mixin.AliasAccessor.AliasBuilder<EventMetaDataBuilder>
-
withChannel
- Specified by:
withChannelin interfaceorg.refcodes.mixin.ChannelAccessor.ChannelBuilder<EventMetaDataBuilder>
-
withGroup
- Specified by:
withGroupin interfaceorg.refcodes.mixin.GroupAccessor.GroupBuilder<EventMetaDataBuilder>
-
withPublisherType
The least common denominator in event Meta-Data is the type of the publisher which gives a hint on the source of the event.- Parameters:
aPublisherType- The type of the publisher who published the event.- Returns:
- The builder for applying multiple build operations.
-
withUniversalId
- Specified by:
withUniversalIdin interfaceorg.refcodes.mixin.UniversalIdAccessor.UniversalIdBuilder<EventMetaDataBuilder>
-