Interface MetaDataActionEvent<A, EM extends EventMetaData, SRC>

Type Parameters:
A - The type of the action stored in the event.
EM - The type of the EventMetaData
SRC - The type of the source in question.
All Superinterfaces:
ActionAccessor<A>, ActionEvent<A,SRC>, Event<SRC>, MetaDataAccessor<EM>, MetaDataEvent<EM,SRC>, SourceAccessor<SRC>
All Known Implementing Classes:
AbstractMetaDataActionEvent

public interface MetaDataActionEvent<A, EM extends EventMetaData, SRC> extends ActionEvent<A,SRC>, MetaDataEvent<EM,SRC>
An MetaDataActionEvent provides Meta-Data describing the ActionEvent in more detail and a source being the origin of the MetaDataActionEvent.