Interface MetaDataEventMatcher<E extends MetaDataEvent<?,?>>

Type Parameters:
E - The matchee type
All Superinterfaces:
AliasAccessor, Diagnosable, EventMatcher<E>, Matchable<E>, Matcher<E>, Schemable<DiagnosticOptions>

public interface MetaDataEventMatcher<E extends MetaDataEvent<?,?>> extends EventMatcher<E>
This interface typifies the Matcher interface for the usage with MetaDataEvent instances. An EventMatcher most commonly uses the EventMetaData (as defined with the MetaDataEvent) in order to determine whether an ActionEvent matches EventMetaData properties or not.
  • Method Details

    • isMatching

      boolean isMatching(E aEvent)
      Tests whether the given event is matching the mathcer's criteria.
      Specified by:
      isMatching in interface EventMatcher<E extends MetaDataEvent<?,?>>
      Specified by:
      isMatching in interface Matchable<E extends MetaDataEvent<?,?>>
      Parameters:
      aEvent - The event used for testing its matchability.
      Returns:
      True in case the event matches the matcher's criteria, else false.