Interface Observable<O>

Type Parameters:
O - The observer type (event listener) observing the Observer.
All Known Implementing Classes:
AbstractObservable

public interface Observable<O>
The Observable interface can be implemented by any class which can be observed by Observer instances (proposal) or any listener interface (custom as of your needs). Whenever something interesting happens to the Observable, then the listeners are informed according to the Observable's implementation. Please regard the listener's documentation on the behavior of the actual listener's methods. Extends it with further functionality using the Observers interface.