Interface Observer<E extends Event<?>>

Type Parameters:
E - the element type
All Known Implementing Classes:
ObserverDescriptor
Functional Interface:
This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.

@FunctionalInterface public interface Observer<E extends Event<?>>
The listener of an event subscriber to be fed with events by a event publisher.