Class PayloadMetaDataActionEventBuilderImpl<P>

All Implemented Interfaces:
org.refcodes.mixin.ActionAccessor<Enum<?>>, org.refcodes.mixin.ActionAccessor.ActionBuilder<Enum<?>,​PayloadMetaDataActionEvent.ActionPayloadMetaDataEventBuilder<P>>, org.refcodes.mixin.ActionAccessor.ActionMutator<Enum<?>>, org.refcodes.mixin.ActionAccessor.ActionProperty<Enum<?>>, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.AliasAccessor.AliasBuilder<org.refcodes.mixin.EventMetaData.EventMetaDataBuilder>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasProperty, org.refcodes.mixin.ChannelAccessor, org.refcodes.mixin.ChannelAccessor.ChannelBuilder<org.refcodes.mixin.EventMetaData.EventMetaDataBuilder>, org.refcodes.mixin.ChannelAccessor.ChannelMutator, org.refcodes.mixin.ChannelAccessor.ChannelProperty, org.refcodes.mixin.EventMetaData, org.refcodes.mixin.EventMetaData.EventMetaDataBuilder, org.refcodes.mixin.GroupAccessor, org.refcodes.mixin.GroupAccessor.GroupBuilder<org.refcodes.mixin.EventMetaData.EventMetaDataBuilder>, org.refcodes.mixin.GroupAccessor.GroupMutator, org.refcodes.mixin.GroupAccessor.GroupProperty, org.refcodes.mixin.MetaDataAccessor<org.refcodes.mixin.EventMetaData>, org.refcodes.mixin.MetaDataAccessor.MetaDataBuilder<org.refcodes.mixin.EventMetaData,​PayloadMetaDataActionEvent.ActionPayloadMetaDataEventBuilder<P>>, org.refcodes.mixin.MetaDataAccessor.MetaDataMutator<org.refcodes.mixin.EventMetaData>, org.refcodes.mixin.MetaDataAccessor.MetaDataProperty<org.refcodes.mixin.EventMetaData>, org.refcodes.mixin.PayloadAccessor<P>, org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P,​PayloadMetaDataActionEvent.ActionPayloadMetaDataEventBuilder<P>>, org.refcodes.mixin.PayloadAccessor.PayloadMutator<P>, org.refcodes.mixin.PayloadAccessor.PayloadProperty<P>, org.refcodes.mixin.SourceAccessor<Object>, org.refcodes.mixin.UniversalIdAccessor, org.refcodes.mixin.UniversalIdAccessor.UniversalIdBuilder<org.refcodes.mixin.EventMetaData.EventMetaDataBuilder>, org.refcodes.mixin.UniversalIdAccessor.UniversalIdMutator, org.refcodes.mixin.UniversalIdAccessor.UniversalIdProperty, ActionEvent, Event, GenericActionEvent<Enum<?>,​Object>, GenericActionMetaDataEvent<Enum<?>,​org.refcodes.mixin.EventMetaData,​Object>, GenericActionMetaDataEvent.GenericActionMetaDataEventBuilder<Enum<?>,​org.refcodes.mixin.EventMetaData,​Object,​PayloadMetaDataActionEvent.ActionPayloadMetaDataEventBuilder<P>>, GenericActionPayloadEvent<Enum<?>,​P,​Object>, GenericActionPayloadMetaDataEvent<Enum<?>,​P,​org.refcodes.mixin.EventMetaData,​Object>, GenericActionPayloadMetaDataEvent.GenericActionPayloadMetaDataEventBuilder<Enum<?>,​P,​org.refcodes.mixin.EventMetaData,​Object,​PayloadMetaDataActionEvent.ActionPayloadMetaDataEventBuilder<P>>, GenericEvent<Object>, GenericMetaDataEvent<org.refcodes.mixin.EventMetaData,​Object>, GenericPayloadEvent<P,​Object>, GenericPayloadMetaDataEvent<P,​org.refcodes.mixin.EventMetaData,​Object>, MetaDataActionEvent, MetaDataEvent, PayloadActionEvent<P>, PayloadEvent<P>, PayloadMetaDataActionEvent<P>, PayloadMetaDataActionEvent.ActionPayloadMetaDataEventBuilder<P>, PayloadMetaDataEvent<P>

public class PayloadMetaDataActionEventBuilderImpl<P>
extends AbstractPayloadMetaDataActionEvent.AbstractActionPayloadMetaDataEventBuilder<Enum<?>,​P,​org.refcodes.mixin.EventMetaData,​Object,​PayloadMetaDataActionEvent.ActionPayloadMetaDataEventBuilder<P>>
implements PayloadMetaDataActionEvent.ActionPayloadMetaDataEventBuilder<P>
Implementation of the PayloadMetaDataActionEvent.ActionPayloadMetaDataEventBuilder interface for easily creating PayloadMetaDataActionEvent instances.
  • Constructor Details

    • PayloadMetaDataActionEventBuilderImpl

      public PayloadMetaDataActionEventBuilderImpl​(Enum<?> aAction, Class<?> aPublisherType, Object aSource)
      Constructs an event with predefined values for the according properties retrieved from the caller's class.
      Parameters:
      aAction - The action which this represents.
      aPublisherType - The type of the event publisher.
      aSource - The source from which this event originated.
    • PayloadMetaDataActionEventBuilderImpl

      public PayloadMetaDataActionEventBuilderImpl​(Enum<?> aAction, String aChannel, Object aSource)
      Constructs an event with predefined values for the according properties retrieved from the caller's class.
      Parameters:
      aAction - The action which this represents.
      aChannel - The channel name on which the event is receivable.
      aSource - The source from which this event originated.
    • PayloadMetaDataActionEventBuilderImpl

      public PayloadMetaDataActionEventBuilderImpl​(Enum<?> aAction, String aAlias, String aGroup, String aChannel, String aUid, Class<?> aPublisherType, Object aSource)
      Constructs an event with the given values for the according properties.
      Parameters:
      aAction - The action which this represents.
      aAlias - The alias property.
      aGroup - The group property.
      aChannel - The channel property.
      aUid - The UID (Universal-TID) property.
      aPublisherType - The type of the event publisher.
      aSource - The source from which this event originated.
    • PayloadMetaDataActionEventBuilderImpl

      public PayloadMetaDataActionEventBuilderImpl​(Enum<?> aAction, org.refcodes.mixin.EventMetaData aEventMetaData, Object aSource)
      Constructs an event with the given Meta-Data.
      Parameters:
      aAction - The action which this represents.
      aEventMetaData - The Meta-Data to by supplied by the event.
      aSource - The source from which this event originated.
    • PayloadMetaDataActionEventBuilderImpl

      public PayloadMetaDataActionEventBuilderImpl​(Enum<?> aAction, Object aSource)
      Constructs an event with the given Meta-Data.
      Parameters:
      aAction - The action which this represents.
      aSource - The source from which this event originated.
    • PayloadMetaDataActionEventBuilderImpl

      public PayloadMetaDataActionEventBuilderImpl​(Enum<?> aAction, P aPayload, org.refcodes.mixin.EventMetaData aEventMetaData, Object aSource)
      Constructs an event with the given Meta-Data.
      Parameters:
      aAction - The action which the event represents.
      aPayload - The payload to be carried by the event.
      aEventMetaData - The Meta-Data to by supplied by the event.
      aSource - The source from which this event originated.
    • PayloadMetaDataActionEventBuilderImpl

      public PayloadMetaDataActionEventBuilderImpl​(Enum<?> aAction, P aPayload, Object aSource)
      Constructs an event with the given Meta-Data.
      Parameters:
      aAction - The action which the event represents.
      aPayload - The payload to be carried by the event.
      aSource - The source from which this event originated.
    • PayloadMetaDataActionEventBuilderImpl

      public PayloadMetaDataActionEventBuilderImpl​(Class<?> aPublisherType, Object aSource)
      Constructs an event with predefined values for the according properties retrieved from the caller's class.
      Parameters:
      aPublisherType - The type of the event publisher.
      aSource - The source from which this event originated.
    • PayloadMetaDataActionEventBuilderImpl

      public PayloadMetaDataActionEventBuilderImpl​(String aChannel, Object aSource)
      Constructs an event with predefined values for the according properties retrieved from the caller's class.
      Parameters:
      aChannel - The channel name on which the event is receivable.
      aSource - The source from which this event originated.
    • PayloadMetaDataActionEventBuilderImpl

      public PayloadMetaDataActionEventBuilderImpl​(String aAlias, String aGroup, String aChannel, String aUid, Class<?> aPublisherType, Object aSource)
      Constructs an event with the given values for the according properties.
      Parameters:
      aAlias - The alias property.
      aGroup - The group property.
      aChannel - The channel property.
      aUid - The UID (Universal-TID) property.
      aPublisherType - The type of the event publisher.
      aSource - The source from which this event originated.
    • PayloadMetaDataActionEventBuilderImpl

      public PayloadMetaDataActionEventBuilderImpl​(org.refcodes.mixin.EventMetaData aEventMetaData, Object aSource)
      Constructs an event with the given Meta-Data.
      Parameters:
      aEventMetaData - The Meta-Data to by supplied by the event.
      aSource - The source from which this event originated.
    • PayloadMetaDataActionEventBuilderImpl

      public PayloadMetaDataActionEventBuilderImpl​(Object aSource)
      Constructs an event with the given Meta-Data.
      Parameters:
      aSource - The source from which this event originated.
    • PayloadMetaDataActionEventBuilderImpl

      public PayloadMetaDataActionEventBuilderImpl​(P aPayload, org.refcodes.mixin.EventMetaData aEventMetaData, Object aSource)
      Constructs an event with the given Meta-Data.
      Parameters:
      aPayload - The payload to be carried by the event.
      aEventMetaData - The Meta-Data to by supplied by the event.
      aSource - The source from which this event originated.
    • PayloadMetaDataActionEventBuilderImpl

      public PayloadMetaDataActionEventBuilderImpl​(P aPayload, Object aSource)
      Constructs an event with the given Meta-Data.
      Parameters:
      aPayload - The payload to be carried by the event.
      aSource - The source from which this event originated.
  • Method Details

    • setPublisherType

      public void setPublisherType​(Class<?> aPublisherType)
      Specified by:
      setPublisherType in interface org.refcodes.mixin.EventMetaData.EventMetaDataBuilder
    • setUniversalId

      public void setUniversalId​(String aUid)
      Specified by:
      setUniversalId in interface org.refcodes.mixin.UniversalIdAccessor.UniversalIdMutator
    • setAlias

      public void setAlias​(String aAlias)
      Specified by:
      setAlias in interface org.refcodes.mixin.AliasAccessor.AliasMutator
    • setGroup

      public void setGroup​(String aGroup)
      Specified by:
      setGroup in interface org.refcodes.mixin.GroupAccessor.GroupMutator
    • setChannel

      public void setChannel​(String aChannel)
      Specified by:
      setChannel in interface org.refcodes.mixin.ChannelAccessor.ChannelMutator
    • setMetaData

      public void setMetaData​(org.refcodes.mixin.EventMetaData aMetaData)
      Specified by:
      setMetaData in interface org.refcodes.mixin.MetaDataAccessor.MetaDataMutator<P>
    • getMetaData

      public org.refcodes.mixin.EventMetaData.EventMetaDataBuilder getMetaData()
      Specified by:
      getMetaData in interface org.refcodes.mixin.MetaDataAccessor<P>
      Overrides:
      getMetaData in class AbstractMetaDataActionEvent<Enum<?>,​org.refcodes.mixin.EventMetaData,​Object>