Class PayloadMetaDataActionEventImpl<P>

java.lang.Object
org.refcodes.observer.AbstractEvent<SRC>
org.refcodes.observer.AbstractActionEvent<A,​SRC>
org.refcodes.observer.AbstractMetaDataActionEvent<A,​EM,​SRC>
org.refcodes.observer.AbstractPayloadMetaDataActionEvent<Enum<?>,​P,​org.refcodes.mixin.EventMetaData,​Object>
org.refcodes.observer.PayloadMetaDataActionEventImpl<P>
Type Parameters:
P - The type of the payload to be carried.
All Implemented Interfaces:
org.refcodes.mixin.ActionAccessor<Enum<?>>, org.refcodes.mixin.MetaDataAccessor<org.refcodes.mixin.EventMetaData>, org.refcodes.mixin.PayloadAccessor<P>, org.refcodes.mixin.SourceAccessor<Object>, ActionEvent, Event, GenericActionEvent<Enum<?>,​Object>, GenericActionMetaDataEvent<Enum<?>,​org.refcodes.mixin.EventMetaData,​Object>, GenericActionPayloadEvent<Enum<?>,​P,​Object>, GenericActionPayloadMetaDataEvent<Enum<?>,​P,​org.refcodes.mixin.EventMetaData,​Object>, GenericEvent<Object>, GenericMetaDataEvent<org.refcodes.mixin.EventMetaData,​Object>, GenericPayloadEvent<P,​Object>, GenericPayloadMetaDataEvent<P,​org.refcodes.mixin.EventMetaData,​Object>, MetaDataActionEvent, MetaDataEvent, PayloadActionEvent<P>, PayloadEvent<P>, PayloadMetaDataActionEvent<P>, PayloadMetaDataEvent<P>

public class PayloadMetaDataActionEventImpl<P>
extends AbstractPayloadMetaDataActionEvent<Enum<?>,​P,​org.refcodes.mixin.EventMetaData,​Object>
implements PayloadMetaDataActionEvent<P>
Basic implementation of the AbstractPayloadMetaDataActionEvent.
  • Constructor Details

    • PayloadMetaDataActionEventImpl

      public PayloadMetaDataActionEventImpl​(Enum<?> aAction, Class<?> aPublisherType, Object aSource)
      Constructs an event with predefined values for the according properties retrieved from the caller's class.
      Parameters:
      aAction - The action which this represents.
      aPublisherType - The type of the event publisher.
      aSource - The source from which this event originated.
    • PayloadMetaDataActionEventImpl

      public PayloadMetaDataActionEventImpl​(Enum<?> aAction, String aChannel, Object aSource)
      Constructs an event with predefined values for the according properties retrieved from the caller's class.
      Parameters:
      aAction - The action which this represents.
      aChannel - The channel name on which the event is receivable.
      aSource - The source from which this event originated.
    • PayloadMetaDataActionEventImpl

      public PayloadMetaDataActionEventImpl​(Enum<?> aAction, String aAlias, String aGroup, String aChannel, String aUid, Class<?> aPublisherType, Object aSource)
      Constructs an event with the given values for the according properties.
      Parameters:
      aAction - The action which this represents.
      aAlias - The alias property.
      aGroup - The group property.
      aChannel - The channel property.
      aUid - The UID (Universal-TID) property.
      aPublisherType - The type of the event publisher.
      aSource - The source from which this event originated.
    • PayloadMetaDataActionEventImpl

      public PayloadMetaDataActionEventImpl​(Enum<?> aAction, org.refcodes.mixin.EventMetaData aEventMetaData, Object aSource)
      Constructs an event with the given Meta-Data.
      Parameters:
      aAction - The action which this represents.
      aEventMetaData - The Meta-Data to by supplied by the event.
      aSource - The source from which this event originated.
    • PayloadMetaDataActionEventImpl

      public PayloadMetaDataActionEventImpl​(Enum<?> aAction, Object aSource)
      Constructs an event with the given Meta-Data.
      Parameters:
      aAction - The action which this represents.
      aSource - The source from which this event originated.
    • PayloadMetaDataActionEventImpl

      public PayloadMetaDataActionEventImpl​(Enum<?> aAction, P aPayload, org.refcodes.mixin.EventMetaData aEventMetaData, Object aSource)
      Constructs an event with the given Meta-Data.
      Parameters:
      aAction - The action which the event represents.
      aPayload - The payload to be carried by the event.
      aEventMetaData - The Meta-Data to by supplied by the event.
      aSource - The source from which this event originated.
    • PayloadMetaDataActionEventImpl

      public PayloadMetaDataActionEventImpl​(Enum<?> aAction, P aPayload, Object aSource)
      Constructs an event with the given Meta-Data.
      Parameters:
      aAction - The action which the event represents.
      aPayload - The payload to be carried by the event.
      aSource - The source from which this event originated.
    • PayloadMetaDataActionEventImpl

      public PayloadMetaDataActionEventImpl​(P aPayload, org.refcodes.mixin.EventMetaData aEventMetaData, Object aSource)
      Constructs an event with the given Meta-Data.
      Parameters:
      aPayload - The payload to be carried by the event.
      aEventMetaData - The Meta-Data to by supplied by the event.
      aSource - The source from which this event originated.
    • PayloadMetaDataActionEventImpl

      public PayloadMetaDataActionEventImpl​(P aPayload, Object aSource)
      Constructs an event with the given Meta-Data.
      Parameters:
      aPayload - The payload to be carried by the event.
      aSource - The source from which this event originated.