Module org.refcodes.observer
Package org.refcodes.observer
Class PublisherIsAssignableFromMatcher<E extends MetaDataEvent<?,?>,PT>
java.lang.Object
org.refcodes.observer.AbstractEventMatcher<E>
org.refcodes.observer.PublisherIsAssignableFromMatcher<E,PT>
- Type Parameters:
E- The matchee type.PT- The publisher type.
- All Implemented Interfaces:
org.refcodes.matcher.Matchable<E>,org.refcodes.matcher.Matcher<E>,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.Schemable,EventMatcher<E>
public class PublisherIsAssignableFromMatcher<E extends MetaDataEvent<?,?>,PT>
extends AbstractEventMatcher<E>
Matches by event publisher type (EVENT PUBLISHER TYPE).
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasProperty -
Field Summary
Fields -
Constructor Summary
ConstructorsConstructorDescriptionPublisherIsAssignableFromMatcher(Class<? extends PT> aEventPublisherType) Instantiates a new publisher is assignable from matcher impl. -
Method Summary
Modifier and TypeMethodDescriptionbooleanisMatching(E aEvent) Tests whether the givenActionEventis matching theMatcher's criteria.org.refcodes.matcher.MatcherSchematoSchema()Methods inherited from class org.refcodes.observer.AbstractEventMatcher
getAlias
-
Field Details
-
ALIAS
- See Also:
-
-
Constructor Details
-
PublisherIsAssignableFromMatcher
Instantiates a new publisher is assignable from matcher impl.- Parameters:
aEventPublisherType- the event publisher type
-
-
Method Details
-
isMatching
Tests whether the givenActionEventis matching theMatcher's criteria.- Parameters:
aEvent- TheActionEventused for testing its matchability.- Returns:
- True in case the
ActionEventmatches theMatcher's criteria, else false.
-
toSchema
public org.refcodes.matcher.MatcherSchema toSchema()- Specified by:
toSchemain interfaceorg.refcodes.matcher.Matcher<E extends MetaDataEvent<?,?>> - Specified by:
toSchemain interfaceorg.refcodes.mixin.Schemable- Overrides:
toSchemain classAbstractEventMatcher<E extends MetaDataEvent<?,?>>
-