Class SubscribeEvent<SRC>

java.lang.Object
org.refcodes.observer.AbstractEvent<SRC>
org.refcodes.observer.SubscribeEvent<SRC>
Type Parameters:
SRC - The type of the observable.
All Implemented Interfaces:
SourceAccessor<SRC>, Event<SRC>

public class SubscribeEvent<SRC> extends AbstractEvent<SRC>

An SubscribeEvent is published by an Observable when an observer is being subscribed.

An SubscribeEvent provides a observable being the origin of the SubscribeEvent.

  • Constructor Details

    • SubscribeEvent

      public SubscribeEvent(SRC aSource)
      Instantiates a new subscribe event.
      Parameters:
      aSource - The according source (origin).