Class UnsubscribeEvent<SRC>

java.lang.Object
org.refcodes.observer.AbstractEvent<SRC>
org.refcodes.observer.UnsubscribeEvent<SRC>
Type Parameters:
SRC - The type of the observable.
All Implemented Interfaces:
SourceAccessor<SRC>, Event<SRC>

public class UnsubscribeEvent<SRC> extends AbstractEvent<SRC>

An UnsubscribeEvent is published by an Observable when an observer is being unsubscribed.

An UnsubscribeEvent provides a observable being the origin of the UnsubscribeEvent.

  • Constructor Details

    • UnsubscribeEvent

      public UnsubscribeEvent(SRC aSource)
      Instantiates a new unsubscribe event.
      Parameters:
      aSource - The according source (origin).