-
class
Matches the given action with the action stored in an event's metadata
(ACTION EQUAL WITH).
class
Matches the given alias with the alias stored in an event's metadata (ALIAS
EQUAL WITH).
class
Catches all events, no matching is done (CATCH ALL).
class
Catches no events, no matching is done (CATCH NONE).
class
Matches the given channel with the channel stored in an event's metadata
(CHANNEL EQUAL WITH).
class
Matches the given group with the group stored in an event's metadata (GROUP
EQUAL WITH).
class
Matches by event publisher type (EVENT PUBLISHER TYPE).
class
Matches the given universal ID with the universal ID stored in an event's
metadata (UNIVERSAL ID EQUAL WITH).