Uses of Class
org.refcodes.observer.EventMetaDataBuilder
-
Uses of EventMetaDataBuilder in org.refcodes.observer
Methods in org.refcodes.observer that return EventMetaDataBuilderModifier and TypeMethodDescriptionEventMetaDataBuilder.withChannel(String aChannel) EventMetaDataBuilder.withPublisherType(Class<?> aPublisherType) The least common denominator in event Meta-Data is the type of the publisher which gives a hint on the source of the event.EventMetaDataBuilder.withUniversalId(String aUid)