Uses of Interface
org.refcodes.observer.MetaDataActionEvent
-
Uses of MetaDataActionEvent in org.refcodes.observer
Classes in org.refcodes.observer with type parameters of type MetaDataActionEventModifier and TypeClassDescriptionclassActionEqualWithEventMatcher<E extends MetaDataActionEvent<?,?, ?>> Matches the given action with the action stored in an event's meta data (ACTION EQUAL WITH).Classes in org.refcodes.observer that implement MetaDataActionEventModifier and TypeClassDescriptionclassAbstractMetaDataActionEvent<A,EM extends EventMetaData, SRC> TheAbstractMetaDataActionEventprovides a base implementation for anMetaDataActionEvent.Methods in org.refcodes.observer with type parameters of type MetaDataActionEventModifier and TypeMethodDescriptionstatic <E extends MetaDataActionEvent<A,?, ?>, A>
EventMatcher<E>EventMatcherSugar.actionEqualWith(A aAction) Factory method to create an "ACTION EQUAL WITH" matcher for the given action compared with the action stored in theEventMetaData.