Uses of Interface
org.refcodes.observer.MetaDataEvent
-
Uses of MetaDataEvent in org.refcodes.observer
Classes in org.refcodes.observer with type parameters of type MetaDataEventModifier and TypeClassDescriptionclassAliasEqualWithEventMatcher<E extends MetaDataEvent<?,?>> Matches the given alias with the alias stored in an event's meta data (ALIAS EQUAL WITH).classCatchAllEventMatcher<E extends MetaDataEvent<?,?>> Catches all events, no matching is done (CATCH ALL).classCatchNoneEventMatcher<E extends MetaDataEvent<?,?>> Catches no events, no matching is done (CATCH NONE).classChannelEqualWithEventMatcher<E extends MetaDataEvent<?,?>> Matches the given channel with the channel stored in an event's meta data (CHANNEL EQUAL WITH).classGroupEqualWithEventMatcher<E extends MetaDataEvent<?,?>> Matches the given group with the group stored in an event's meta data (GROUP EQUAL WITH).interfaceMetaDataEventMatcher<E extends MetaDataEvent<?,?>> This interface typifies theMatcherinterface for the usage withMetaDataEventinstances.classPublisherTypeOfEventMatcher<E extends MetaDataEvent<?,?>, PT> Matches by event publisher type (EVENT PUBLISHER TYPE).classUniversalIdEqualWithEventMatcher<E extends MetaDataEvent<?,?>> Matches the given universal ID with the universal ID stored in an event's meta data (UNIVERSAL ID EQUAL WITH).Subinterfaces of MetaDataEvent in org.refcodes.observerModifier and TypeInterfaceDescriptioninterfaceMetaDataActionEvent<A,EM extends EventMetaData, SRC> AnMetaDataActionEventprovides Meta-Data describing theActionEventin more detail and a source being the origin of theMetaDataActionEvent.Classes in org.refcodes.observer that implement MetaDataEventModifier and TypeClassDescriptionclassAbstractMetaDataActionEvent<A,EM extends EventMetaData, SRC> TheAbstractMetaDataActionEventprovides a base implementation for anMetaDataActionEvent.classAbstractMetaDataEvent<EM extends EventMetaData,SRC> TheAbstractMetaDataEventprovides a base implementation for anMetaDataEvent.Methods in org.refcodes.observer with type parameters of type MetaDataEventModifier and TypeMethodDescriptionstatic <E extends MetaDataEvent<?,?>>
EventMatcher<E>EventMatcherSugar.aliasEqualWith(String aAlias) Factory method to create an "ALIAS EQUAL WITH" matcher for the given alias compared with the alias stored in theEventMetaData.static <E extends MetaDataEvent<?,?>>
EventMatcher<E>EventMatcherSugar.and(EventMatcher<E>... aEventMatchers) Factory method to create an "AND" matcher for the given matchers.static <E extends MetaDataEvent<?,?>>
EventMatcher<E>EventMatcherSugar.catchAll()Catches all events, no matching is done.static <E extends MetaDataEvent<?,?>>
EventMatcher<E>EventMatcherSugar.catchNone()Catches no event, no matching is done.static <E extends MetaDataEvent<?,?>>
EventMatcher<E>EventMatcherSugar.channelEqualWith(String aChannel) Factory method to create an "CHANNEL EQUAL WITH" matcher for the given channel compared with the channel stored in theEventMetaData.static <E extends MetaDataEvent<?,?>>
EventMatcher<E>EventMatcherSugar.groupEqualWith(String aGroup) Factory method to create an "GROUP EQUAL WITH" matcher for the given group compared with the group stored in theEventMetaData.static <E extends MetaDataEvent<?,?>>
EventMatcher<E>EventMatcherSugar.isAssignableFrom(Class<?> aEventType) Factory method to create an event matcher by event type.static <E extends MetaDataEvent<?,?>>
EventMatcher<E>EventMatcherSugar.or(EventMatcher<E>... aEventMatchers) Factory method to create an "OR" matcher for the given matchers.static <E extends MetaDataEvent<?,?>, PT>
EventMatcher<E>EventMatcherSugar.publisherIsAssignableFrom(Class<? extends PT> aPublisherType) Factory method to create an event matcher by event publisher type.static <E extends MetaDataEvent<?,?>>
EventMatcher<E>EventMatcherSugar.universalIdEqualWith(String aUid) Factory method to create an "UNIVERSAL ID EQUAL WITH" matcher for the given UID compared with the UID stored in theEventMetaData.