Uses of Package
org.refcodes.observer
-
Classes in org.refcodes.observer used by org.refcodes.observerClassDescriptionThe
AbstractActionEventprovides a base implementation for anActionEvent.TheAbstractEventprovides a base implementation for anEvent.Abstract implementation of anEventMatchertype.AnActionEventextends theEventand provides additional means to provide an action viaActionAccessor.getAction()being of a generic type.This interface typifies theMatcherinterface for the usage withActionEventinstances.The Meta-Data describes the event which a publisher posts via the event bus to an event subscriber's event listener.Builder to buildEventMetaData.AnMetaDataActionEventprovides Meta-Data describing theActionEventin more detail and a source being the origin of theMetaDataActionEvent.AnMetaDataEventprovides Meta-Data describing theActionEventin more detail and a source being the origin of theMetaDataEvent.TheObservableinterface can be implemented by any class which can be observed byObserverinstances (proposal) or any listener interface (custom as of your needs).The listener of an event subscriber to be fed with events by a event publisher.Provides methods to manage all subscribedObserverinstances as a whole and is intended as an extension of theObservableinterface.Provides an accessor for a publisher's type property.Provides a builder method for a publisher's type property returning the builder for applying multiple build operations.Provides a mutator for a publisher's type property.AnSubscribeEventis published by anObservablewhen an observer is being subscribed.AnUnsubscribeEventis published by anObservablewhen an observer is being unsubscribed.