org.refcodes.mixin.ActionAccessor<Enum<?>>, org.refcodes.mixin.ActionAccessor.ActionBuilder<Enum<?>,EventMetaData>, org.refcodes.mixin.ActionAccessor.ActionMutator<Enum<?>>, org.refcodes.mixin.ActionAccessor.ActionProperty<Enum<?>>, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.AliasAccessor.AliasBuilder<Enum<?>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasProperty, org.refcodes.mixin.ChannelAccessor, org.refcodes.mixin.ChannelAccessor.ChannelBuilder<Enum<?>>, org.refcodes.mixin.ChannelAccessor.ChannelMutator, org.refcodes.mixin.ChannelAccessor.ChannelProperty, org.refcodes.mixin.GroupAccessor, org.refcodes.mixin.GroupAccessor.GroupBuilder<Enum<?>>, org.refcodes.mixin.GroupAccessor.GroupMutator, org.refcodes.mixin.GroupAccessor.GroupProperty, org.refcodes.mixin.MetaDataAccessor<Enum<?>>, org.refcodes.mixin.MetaDataAccessor.MetaDataBuilder<Enum<?>,EventMetaData>, org.refcodes.mixin.MetaDataAccessor.MetaDataMutator<Enum<?>>, org.refcodes.mixin.MetaDataAccessor.MetaDataProperty<Enum<?>>, org.refcodes.mixin.SourceAccessor<Enum<?>>, org.refcodes.mixin.UniversalIdAccessor, org.refcodes.mixin.UniversalIdAccessor.UniversalIdBuilder<Enum<?>>, org.refcodes.mixin.UniversalIdAccessor.UniversalIdMutator, org.refcodes.mixin.UniversalIdAccessor.UniversalIdProperty, ActionEvent, ActionMetaDataEvent, ActionMetaDataEvent.ActionMetaDataEventBuilder, Event, EventMetaData, EventMetaData.EventMetaDataBuilder, GenericActionEvent<Enum<?>,EventMetaData>, GenericActionMetaDataEvent<Enum<?>,EventMetaData,Object>, GenericActionMetaDataEvent.GenericActionMetaDataEventBuilder<Enum<?>,EventMetaData,Object,ActionMetaDataEvent.ActionMetaDataEventBuilder>, GenericEvent<Enum<?>>, GenericMetaDataEvent<Enum<?>,EventMetaData>, MetaDataEventpublic class ActionMetaDataEventBuilderImpl extends AbstractActionMetaDataEvent.AbstractActionMetaDataEventBuilder<Enum<?>,EventMetaData,Object,ActionMetaDataEvent.ActionMetaDataEventBuilder> implements ActionMetaDataEvent.ActionMetaDataEventBuilder
ActionMetaDataEvent.ActionMetaDataEventBuilder interface for easily
creating ActionMetaDataEvent instances.AbstractActionMetaDataEvent.AbstractActionMetaDataEventBuilder<A,EM extends EventMetaData,SRC,B extends GenericActionMetaDataEvent.GenericActionMetaDataEventBuilder<A,EM,SRC,B>>org.refcodes.mixin.ActionAccessor.ActionBuilder<A extends Object,B extends org.refcodes.mixin.ActionAccessor.ActionBuilder<A,B>>, org.refcodes.mixin.ActionAccessor.ActionMutator<A extends Object>, org.refcodes.mixin.ActionAccessor.ActionProperty<A extends Object>ActionMetaDataEvent.ActionMetaDataEventBuilderorg.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyorg.refcodes.mixin.ChannelAccessor.ChannelBuilder<B extends org.refcodes.mixin.ChannelAccessor.ChannelBuilder<B>>, org.refcodes.mixin.ChannelAccessor.ChannelMutator, org.refcodes.mixin.ChannelAccessor.ChannelPropertyEventMetaData.EventMetaDataBuilderGenericActionMetaDataEvent.GenericActionMetaDataEventBuilder<A,EM extends EventMetaData,SRC,B extends GenericActionMetaDataEvent.GenericActionMetaDataEventBuilder<A,EM,SRC,B>>org.refcodes.mixin.GroupAccessor.GroupBuilder<B extends org.refcodes.mixin.GroupAccessor.GroupBuilder<B>>, org.refcodes.mixin.GroupAccessor.GroupMutator, org.refcodes.mixin.GroupAccessor.GroupPropertyorg.refcodes.mixin.MetaDataAccessor.MetaDataBuilder<MD extends Object,B extends org.refcodes.mixin.MetaDataAccessor.MetaDataBuilder<MD,B>>, org.refcodes.mixin.MetaDataAccessor.MetaDataMutator<MD extends Object>, org.refcodes.mixin.MetaDataAccessor.MetaDataProperty<MD extends Object>org.refcodes.mixin.SourceAccessor.SourceMutator<SRC extends Object>, org.refcodes.mixin.SourceAccessor.SourceProperty<SRC extends Object>org.refcodes.mixin.UniversalIdAccessor.UniversalIdBuilder<B extends org.refcodes.mixin.UniversalIdAccessor.UniversalIdBuilder<B>>, org.refcodes.mixin.UniversalIdAccessor.UniversalIdMutator, org.refcodes.mixin.UniversalIdAccessor.UniversalIdProperty_action_eventMetaData| Constructor | Description |
|---|---|
ActionMetaDataEventBuilderImpl(Class<?> aPublisherType,
Object aSource) |
Constructs an event with predefined values for the according properties
retrieved from the caller's class.
|
ActionMetaDataEventBuilderImpl(Enum<?> aAction,
Class<?> aPublisherType,
Object aSource) |
Constructs an event with predefined values for the according properties
retrieved from the caller's class.
|
ActionMetaDataEventBuilderImpl(Enum<?> aAction,
Object aSource) |
Constructs an event with the given Meta-Data.
|
ActionMetaDataEventBuilderImpl(Enum<?> aAction,
String aChannel,
Object aSource) |
Constructs an event with predefined values for the according properties
retrieved from the caller's class.
|
ActionMetaDataEventBuilderImpl(Enum<?> aAction,
String aAlias,
String aGroup,
String aChannel,
String aUid,
Class<?> aPublisherType,
Object aSource) |
Constructs an event with the given values for the according properties.
|
ActionMetaDataEventBuilderImpl(Enum<?> aAction,
EventMetaData aEventMetaData,
Object aSource) |
Constructs an event with the given Meta-Data.
|
ActionMetaDataEventBuilderImpl(Object aSource) |
Constructs an event with the given Meta-Data.
|
ActionMetaDataEventBuilderImpl(String aChannel,
Object aSource) |
Constructs an event with predefined values for the according properties
retrieved from the caller's class.
|
ActionMetaDataEventBuilderImpl(String aAlias,
String aGroup,
String aChannel,
String aUid,
Class<?> aPublisherType,
Object aSource) |
Constructs an event with the given values for the according properties.
|
ActionMetaDataEventBuilderImpl(EventMetaData aEventMetaData,
Object aSource) |
Constructs an event with the given Meta-Data.
|
| Modifier and Type | Method | Description |
|---|---|---|
EventMetaData.EventMetaDataBuilder |
getMetaData() |
|
void |
setAlias(String aAlias) |
|
void |
setChannel(String aChannel) |
|
void |
setGroup(String aGroup) |
|
void |
setMetaData(EventMetaData aMetaData) |
|
void |
setPublisherType(Class<?> aPublisherType) |
The least common denominator in event Meta-Data is the type of the
publisher which gives a hint on the source of the event.
|
void |
setUniversalId(String aUid) |
getActiontoStringgetAlias, getChannel, getGroup, getPublisherType, getUniversalId, setActiongetSourcegetPublisherTypewithAction, withAlias, withChannel, withGroup, withMetaData, withPublisherType, withUniversalIdpublic ActionMetaDataEventBuilderImpl(EventMetaData aEventMetaData, Object aSource)
aEventMetaData - The Meta-Data to by supplied by the event.aSource - The source from which this event originated.public ActionMetaDataEventBuilderImpl(Enum<?> aAction, EventMetaData aEventMetaData, Object aSource)
aAction - The action which the GenericActionEvent
represents.aEventMetaData - The Meta-Data to by supplied by the event.aSource - The source from which this event originated.public ActionMetaDataEventBuilderImpl(Enum<?> aAction, Object aSource)
aAction - The action which the GenericActionEvent
represents.aSource - The source from which this event originated.public ActionMetaDataEventBuilderImpl(Object aSource)
aSource - The source from which this event originated.public ActionMetaDataEventBuilderImpl(Class<?> aPublisherType, Object aSource)
aPublisherType - The type of the event publisher.aSource - The source from which this event originated.public ActionMetaDataEventBuilderImpl(String aChannel, Object aSource)
aChannel - The channel name on which the event is receivable.aSource - The source from which this event originated.public ActionMetaDataEventBuilderImpl(String aAlias, String aGroup, String aChannel, String aUid, Class<?> aPublisherType, Object aSource)
aAlias - The alias property.aGroup - The group property.aChannel - The channel property.aUid - The UID (Universal-ID) property.aPublisherType - The type of the event publisher.aSource - The source from which this event originated.public ActionMetaDataEventBuilderImpl(Enum<?> aAction, Class<?> aPublisherType, Object aSource)
aAction - The action which this represents.aPublisherType - The type of the event publisher.aSource - The source from which this event originated.public ActionMetaDataEventBuilderImpl(Enum<?> aAction, String aChannel, Object aSource)
aAction - The action which this represents.aChannel - The channel name on which the event is receivable.aSource - The source from which this event originated.public ActionMetaDataEventBuilderImpl(Enum<?> aAction, String aAlias, String aGroup, String aChannel, String aUid, Class<?> aPublisherType, Object aSource)
aAction - The action which this represents.aAlias - The alias property.aGroup - The group property.aChannel - The channel property.aUid - The UID (Universal-ID) property.aPublisherType - The type of the event publisher.aSource - The source from which this event originated.public void setPublisherType(Class<?> aPublisherType)
setPublisherType in interface EventMetaData.EventMetaDataBuilderaPublisherType - The type of the publisher who published the
event.public void setUniversalId(String aUid)
setUniversalId in interface org.refcodes.mixin.UniversalIdAccessor.UniversalIdMutatorpublic void setAlias(String aAlias)
setAlias in interface org.refcodes.mixin.AliasAccessor.AliasMutatorpublic void setGroup(String aGroup)
setGroup in interface org.refcodes.mixin.GroupAccessor.GroupMutatorpublic void setChannel(String aChannel)
setChannel in interface org.refcodes.mixin.ChannelAccessor.ChannelMutatorpublic void setMetaData(EventMetaData aMetaData)
setMetaData in interface org.refcodes.mixin.MetaDataAccessor.MetaDataMutator<Enum<?>>public EventMetaData.EventMetaDataBuilder getMetaData()
getMetaData in interface ActionMetaDataEvent.ActionMetaDataEventBuildergetMetaData in interface org.refcodes.mixin.MetaDataAccessor<Enum<?>>getMetaData in class AbstractActionMetaDataEvent<Enum<?>,EventMetaData,Object>Copyright © 2018. All rights reserved.