Package org.refcodes.observer
Class ActionMetaDataEventImpl
- java.lang.Object
-
- org.refcodes.observer.AbstractEvent<SRC>
-
- org.refcodes.observer.AbstractActionEvent<A,SRC>
-
- org.refcodes.observer.AbstractActionMetaDataEvent<Enum<?>,org.refcodes.mixin.EventMetaData,Object>
-
- org.refcodes.observer.ActionMetaDataEventImpl
-
- All Implemented Interfaces:
org.refcodes.mixin.ActionAccessor<Enum<?>>,org.refcodes.mixin.MetaDataAccessor<Enum<?>>,org.refcodes.mixin.SourceAccessor<Enum<?>>,ActionEvent,ActionMetaDataEvent,Event,GenericActionEvent<Enum<?>,org.refcodes.mixin.EventMetaData>,GenericActionMetaDataEvent<Enum<?>,org.refcodes.mixin.EventMetaData,Object>,GenericEvent<Enum<?>>,GenericMetaDataEvent<Enum<?>,org.refcodes.mixin.EventMetaData>,MetaDataEvent
public class ActionMetaDataEventImpl extends AbstractActionMetaDataEvent<Enum<?>,org.refcodes.mixin.EventMetaData,Object> implements ActionMetaDataEvent
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from class org.refcodes.observer.AbstractActionMetaDataEvent
AbstractActionMetaDataEvent.AbstractActionMetaDataEventBuilder<A,EM extends org.refcodes.mixin.EventMetaData,SRC,B extends GenericActionMetaDataEvent.GenericActionMetaDataEventBuilder<A,EM,SRC,B>>
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.ActionAccessor
org.refcodes.mixin.ActionAccessor.ActionBuilder<A extends Object,B extends org.refcodes.mixin.ActionAccessor.ActionBuilder<A,B>>, org.refcodes.mixin.ActionAccessor.ActionMutator<A extends Object>, org.refcodes.mixin.ActionAccessor.ActionProperty<A extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.observer.ActionMetaDataEvent
ActionMetaDataEvent.ActionMetaDataEventBuilder
-
Nested classes/interfaces inherited from interface org.refcodes.observer.GenericActionMetaDataEvent
GenericActionMetaDataEvent.GenericActionMetaDataEventBuilder<A,EM extends org.refcodes.mixin.EventMetaData,SRC,B extends GenericActionMetaDataEvent.GenericActionMetaDataEventBuilder<A,EM,SRC,B>>
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.MetaDataAccessor
org.refcodes.mixin.MetaDataAccessor.MetaDataBuilder<MD extends Object,B extends org.refcodes.mixin.MetaDataAccessor.MetaDataBuilder<MD,B>>, org.refcodes.mixin.MetaDataAccessor.MetaDataMutator<MD extends Object>, org.refcodes.mixin.MetaDataAccessor.MetaDataProperty<MD extends Object>
-
-
Field Summary
-
Fields inherited from class org.refcodes.observer.AbstractActionEvent
_action
-
Fields inherited from class org.refcodes.observer.AbstractActionMetaDataEvent
_eventMetaData
-
-
Constructor Summary
Constructors Constructor Description ActionMetaDataEventImpl(Class<?> aPublisherType, Object aSource)Constructs an event with the according properties.ActionMetaDataEventImpl(Enum<?> aAction, Class<?> aPublisherType, Object aSource)Constructs an event with the according properties.ActionMetaDataEventImpl(Enum<?> aAction, Object aSource)Constructs an event with the given Meta-Data.ActionMetaDataEventImpl(Enum<?> aAction, String aChannel, Object aSource)Constructs an event with the according properties.ActionMetaDataEventImpl(Enum<?> aAction, String aAlias, String aGroup, String aChannel, String aUid, Class<?> aPublisherType, Object aSource)Constructs an event with the given values for the according properties.ActionMetaDataEventImpl(Enum<?> aAction, org.refcodes.mixin.EventMetaData aEventMetaData, Object aSource)Constructs an event with the given Meta-Data.ActionMetaDataEventImpl(Object aSource)Constructs an event with the given Meta-Data.ActionMetaDataEventImpl(String aChannel, Object aSource)Constructs an event with the according properties.ActionMetaDataEventImpl(String aAlias, String aGroup, String aChannel, String aUid, Class<?> aPublisherType, Object aSource)Constructs an event with the given values for the according properties.ActionMetaDataEventImpl(org.refcodes.mixin.EventMetaData aEventMetaData, Object aSource)Constructs an event with the given Meta-Data.
-
Method Summary
-
Methods inherited from class org.refcodes.observer.AbstractActionEvent
getAction
-
Methods inherited from class org.refcodes.observer.AbstractActionMetaDataEvent
getMetaData, toString
-
Methods inherited from class org.refcodes.observer.AbstractEvent
getSource
-
-
-
-
Constructor Detail
-
ActionMetaDataEventImpl
public ActionMetaDataEventImpl(Class<?> aPublisherType, Object aSource)
Constructs an event with the according properties.- Parameters:
aPublisherType- The type of the event publisher.aSource- The source from which this event originated.
-
ActionMetaDataEventImpl
public ActionMetaDataEventImpl(String aChannel, Object aSource)
Constructs an event with the according properties.- Parameters:
aChannel- The channel name on which the event is receivable.aSource- The source from which this event originated.
-
ActionMetaDataEventImpl
public ActionMetaDataEventImpl(String aAlias, String aGroup, String aChannel, String aUid, Class<?> aPublisherType, Object aSource)
Constructs an event with the given values for the according properties.- Parameters:
aAlias- The alias property.aGroup- The group property.aChannel- The channel property.aUid- The UID (Universal-ID) property.aPublisherType- The type of the event publisher.aSource- The source from which this event originated.
-
ActionMetaDataEventImpl
public ActionMetaDataEventImpl(Enum<?> aAction, Class<?> aPublisherType, Object aSource)
Constructs an event with the according properties.- Parameters:
aAction- The action which this represents.aPublisherType- The type of the event publisher.aSource- The source from which this event originated.
-
ActionMetaDataEventImpl
public ActionMetaDataEventImpl(Enum<?> aAction, String aChannel, Object aSource)
Constructs an event with the according properties.- Parameters:
aAction- The action which this represents.aChannel- The channel name on which the event is receivable.aSource- The source from which this event originated.
-
ActionMetaDataEventImpl
public ActionMetaDataEventImpl(Enum<?> aAction, String aAlias, String aGroup, String aChannel, String aUid, Class<?> aPublisherType, Object aSource)
Constructs an event with the given values for the according properties.- Parameters:
aAction- The action which this represents.aAlias- The alias property.aGroup- The group property.aChannel- The channel property.aUid- The UID (Universal-ID) property.aPublisherType- The type of the event publisher.aSource- The source from which this event originated.
-
ActionMetaDataEventImpl
public ActionMetaDataEventImpl(org.refcodes.mixin.EventMetaData aEventMetaData, Object aSource)Constructs an event with the given Meta-Data.- Parameters:
aEventMetaData- The Meta-Data to by supplied by the event.aSource- The source from which this event originated.
-
ActionMetaDataEventImpl
public ActionMetaDataEventImpl(Enum<?> aAction, org.refcodes.mixin.EventMetaData aEventMetaData, Object aSource)
Constructs an event with the given Meta-Data.- Parameters:
aAction- The action which this represents.aEventMetaData- The Meta-Data to by supplied by the event.aSource- The source from which this event originated.
-
ActionMetaDataEventImpl
public ActionMetaDataEventImpl(Enum<?> aAction, Object aSource)
Constructs an event with the given Meta-Data.- Parameters:
aAction- The action which this represents.aSource- The source from which this event originated.
-
ActionMetaDataEventImpl
public ActionMetaDataEventImpl(Object aSource)
Constructs an event with the given Meta-Data.- Parameters:
aSource- The source from which this event originated.
-
-