org.refcodes.mixin.ActionAccessor<P>, org.refcodes.mixin.ActionAccessor.ActionBuilder<A,B>, org.refcodes.mixin.ActionAccessor.ActionMutator<P>, org.refcodes.mixin.ActionAccessor.ActionProperty<P>, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.AliasAccessor.AliasBuilder<P>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasProperty, org.refcodes.mixin.ChannelAccessor, org.refcodes.mixin.ChannelAccessor.ChannelBuilder<P>, org.refcodes.mixin.ChannelAccessor.ChannelMutator, org.refcodes.mixin.ChannelAccessor.ChannelProperty, org.refcodes.mixin.GroupAccessor, org.refcodes.mixin.GroupAccessor.GroupBuilder<P>, org.refcodes.mixin.GroupAccessor.GroupMutator, org.refcodes.mixin.GroupAccessor.GroupProperty, org.refcodes.mixin.MetaDataAccessor<P>, org.refcodes.mixin.MetaDataAccessor.MetaDataBuilder<EM,B>, org.refcodes.mixin.MetaDataAccessor.MetaDataMutator<P>, org.refcodes.mixin.MetaDataAccessor.MetaDataProperty<P>, org.refcodes.mixin.PayloadAccessor<P>, org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P,B>, org.refcodes.mixin.PayloadAccessor.PayloadMutator<P>, org.refcodes.mixin.PayloadAccessor.PayloadProperty<P>, org.refcodes.mixin.SourceAccessor<P>, org.refcodes.mixin.UniversalIdAccessor, org.refcodes.mixin.UniversalIdAccessor.UniversalIdBuilder<P>, org.refcodes.mixin.UniversalIdAccessor.UniversalIdMutator, org.refcodes.mixin.UniversalIdAccessor.UniversalIdProperty, ActionEvent, ActionMetaDataEvent, ActionPayloadEvent<P>, ActionPayloadMetaDataEvent<P>, ActionPayloadMetaDataEvent.ActionPayloadMetaDataEventBuilder<P>, Event, EventMetaData, EventMetaData.EventMetaDataBuilder, GenericActionEvent<Enum<?>,EventMetaData>, GenericActionMetaDataEvent<Enum<?>,EventMetaData,Object>, GenericActionMetaDataEvent.GenericActionMetaDataEventBuilder<Enum<?>,EventMetaData,Object,ActionPayloadMetaDataEvent.ActionPayloadMetaDataEventBuilder<P>>, GenericActionPayloadEvent<A,P,SRC>, GenericActionPayloadMetaDataEvent<Enum<?>,P,EventMetaData,Object>, GenericActionPayloadMetaDataEvent.GenericActionPayloadMetaDataEventBuilder<Enum<?>,P,EventMetaData,Object,ActionPayloadMetaDataEvent.ActionPayloadMetaDataEventBuilder<P>>, GenericEvent<P>, GenericMetaDataEvent<Enum<?>,EventMetaData>, GenericPayloadEvent<P,SRC>, GenericPayloadMetaDataEvent<P,EventMetaData,Object>, MetaDataEvent, PayloadEvent<P>, PayloadMetaDataEvent<P>public class ActionPayloadMetaDataEventBuilderImpl<P> extends AbstractActionPayloadMetaDataEvent.AbstractActionPayloadMetaDataEventBuilder<Enum<?>,P,EventMetaData,Object,ActionPayloadMetaDataEvent.ActionPayloadMetaDataEventBuilder<P>> implements ActionPayloadMetaDataEvent.ActionPayloadMetaDataEventBuilder<P>
ActionPayloadMetaDataEvent.ActionPayloadMetaDataEventBuilder interface for
easily creating ActionPayloadMetaDataEvent instances.AbstractActionMetaDataEvent.AbstractActionMetaDataEventBuilder<A,EM extends EventMetaData,SRC,B extends GenericActionMetaDataEvent.GenericActionMetaDataEventBuilder<A,EM,SRC,B>>org.refcodes.mixin.ActionAccessor.ActionBuilder<A extends Object,B extends org.refcodes.mixin.ActionAccessor.ActionBuilder<A,B>>, org.refcodes.mixin.ActionAccessor.ActionMutator<A extends Object>, org.refcodes.mixin.ActionAccessor.ActionProperty<A extends Object>ActionMetaDataEvent.ActionMetaDataEventBuilderActionPayloadMetaDataEvent.ActionPayloadMetaDataEventBuilder<P>org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyorg.refcodes.mixin.ChannelAccessor.ChannelBuilder<B extends org.refcodes.mixin.ChannelAccessor.ChannelBuilder<B>>, org.refcodes.mixin.ChannelAccessor.ChannelMutator, org.refcodes.mixin.ChannelAccessor.ChannelPropertyEventMetaData.EventMetaDataBuilderGenericActionMetaDataEvent.GenericActionMetaDataEventBuilder<A,EM extends EventMetaData,SRC,B extends GenericActionMetaDataEvent.GenericActionMetaDataEventBuilder<A,EM,SRC,B>>GenericActionPayloadMetaDataEvent.GenericActionPayloadMetaDataEventBuilder<A,P,EM extends EventMetaData,SRC,B extends GenericActionPayloadMetaDataEvent.GenericActionPayloadMetaDataEventBuilder<A,P,EM,SRC,B>>org.refcodes.mixin.GroupAccessor.GroupBuilder<B extends org.refcodes.mixin.GroupAccessor.GroupBuilder<B>>, org.refcodes.mixin.GroupAccessor.GroupMutator, org.refcodes.mixin.GroupAccessor.GroupPropertyorg.refcodes.mixin.MetaDataAccessor.MetaDataBuilder<MD extends Object,B extends org.refcodes.mixin.MetaDataAccessor.MetaDataBuilder<MD,B>>, org.refcodes.mixin.MetaDataAccessor.MetaDataMutator<MD extends Object>, org.refcodes.mixin.MetaDataAccessor.MetaDataProperty<MD extends Object>org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P extends Object,B extends org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P,B>>, org.refcodes.mixin.PayloadAccessor.PayloadMutator<P extends Object>, org.refcodes.mixin.PayloadAccessor.PayloadProperty<P extends Object>org.refcodes.mixin.SourceAccessor.SourceMutator<SRC extends Object>, org.refcodes.mixin.SourceAccessor.SourceProperty<SRC extends Object>org.refcodes.mixin.UniversalIdAccessor.UniversalIdBuilder<B extends org.refcodes.mixin.UniversalIdAccessor.UniversalIdBuilder<B>>, org.refcodes.mixin.UniversalIdAccessor.UniversalIdMutator, org.refcodes.mixin.UniversalIdAccessor.UniversalIdProperty_action_eventMetaData| Constructor | Description |
|---|---|
ActionPayloadMetaDataEventBuilderImpl(Class<?> aPublisherType,
Object aSource) |
Constructs an event with predefined values for the according properties
retrieved from the caller's class.
|
ActionPayloadMetaDataEventBuilderImpl(Enum<?> aAction,
Class<?> aPublisherType,
Object aSource) |
Constructs an event with predefined values for the according properties
retrieved from the caller's class.
|
ActionPayloadMetaDataEventBuilderImpl(Enum<?> aAction,
Object aSource) |
Constructs an event with the given Meta-Data.
|
ActionPayloadMetaDataEventBuilderImpl(Enum<?> aAction,
String aChannel,
Object aSource) |
Constructs an event with predefined values for the according properties
retrieved from the caller's class.
|
ActionPayloadMetaDataEventBuilderImpl(Enum<?> aAction,
String aAlias,
String aGroup,
String aChannel,
String aUid,
Class<?> aPublisherType,
Object aSource) |
Constructs an event with the given values for the according properties.
|
ActionPayloadMetaDataEventBuilderImpl(Enum<?> aAction,
EventMetaData aEventMetaData,
Object aSource) |
Constructs an event with the given Meta-Data.
|
ActionPayloadMetaDataEventBuilderImpl(Enum<?> aAction,
P aPayload,
Object aSource) |
Constructs an event with the given Meta-Data.
|
ActionPayloadMetaDataEventBuilderImpl(Enum<?> aAction,
P aPayload,
EventMetaData aEventMetaData,
Object aSource) |
Constructs an event with the given Meta-Data.
|
ActionPayloadMetaDataEventBuilderImpl(Object aSource) |
Constructs an event with the given Meta-Data.
|
ActionPayloadMetaDataEventBuilderImpl(String aChannel,
Object aSource) |
Constructs an event with predefined values for the according properties
retrieved from the caller's class.
|
ActionPayloadMetaDataEventBuilderImpl(String aAlias,
String aGroup,
String aChannel,
String aUid,
Class<?> aPublisherType,
Object aSource) |
Constructs an event with the given values for the according properties.
|
ActionPayloadMetaDataEventBuilderImpl(EventMetaData aEventMetaData,
Object aSource) |
Constructs an event with the given Meta-Data.
|
ActionPayloadMetaDataEventBuilderImpl(P aPayload,
Object aSource) |
Constructs an event with the given Meta-Data.
|
ActionPayloadMetaDataEventBuilderImpl(P aPayload,
EventMetaData aEventMetaData,
Object aSource) |
Constructs an event with the given Meta-Data.
|
| Modifier and Type | Method | Description |
|---|---|---|
EventMetaData.EventMetaDataBuilder |
getMetaData() |
|
void |
setAlias(String aAlias) |
|
void |
setChannel(String aChannel) |
|
void |
setGroup(String aGroup) |
|
void |
setMetaData(EventMetaData aMetaData) |
|
void |
setPublisherType(Class<?> aPublisherType) |
The least common denominator in event Meta-Data is the type of the
publisher which gives a hint on the source of the event.
|
void |
setUniversalId(String aUid) |
getActiontoStringgetAlias, getChannel, getGroup, getPublisherType, getUniversalId, setActiongetPayload, setPayloadgetSourcewithAction, withAlias, withChannel, withGroup, withMetaData, withPayload, withPublisherType, withUniversalIdgetPublisherTypepublic ActionPayloadMetaDataEventBuilderImpl(Enum<?> aAction, Class<?> aPublisherType, Object aSource)
aAction - The action which this represents.aPublisherType - The type of the event publisher.aSource - The source from which this event originated.public ActionPayloadMetaDataEventBuilderImpl(Enum<?> aAction, String aChannel, Object aSource)
aAction - The action which this represents.aChannel - The channel name on which the event is receivable.aSource - The source from which this event originated.public ActionPayloadMetaDataEventBuilderImpl(Enum<?> aAction, String aAlias, String aGroup, String aChannel, String aUid, Class<?> aPublisherType, Object aSource)
aAction - The action which this represents.aAlias - The alias property.aGroup - The group property.aChannel - The channel property.aUid - The UID (Universal-ID) property.aPublisherType - The type of the event publisher.aSource - The source from which this event originated.public ActionPayloadMetaDataEventBuilderImpl(Enum<?> aAction, EventMetaData aEventMetaData, Object aSource)
aAction - The action which this represents.aEventMetaData - The Meta-Data to by supplied by the event.aSource - The source from which this event originated.public ActionPayloadMetaDataEventBuilderImpl(Enum<?> aAction, Object aSource)
aAction - The action which this represents.aSource - The source from which this event originated.public ActionPayloadMetaDataEventBuilderImpl(Enum<?> aAction, P aPayload, EventMetaData aEventMetaData, Object aSource)
aAction - The action which the event represents.aPayload - The payload to be carried by the event.aEventMetaData - The Meta-Data to by supplied by the event.aSource - The source from which this event originated.public ActionPayloadMetaDataEventBuilderImpl(Enum<?> aAction, P aPayload, Object aSource)
aAction - The action which the event represents.aPayload - The payload to be carried by the event.aSource - The source from which this event originated.public ActionPayloadMetaDataEventBuilderImpl(Class<?> aPublisherType, Object aSource)
aPublisherType - The type of the event publisher.aSource - The source from which this event originated.public ActionPayloadMetaDataEventBuilderImpl(String aChannel, Object aSource)
aChannel - The channel name on which the event is receivable.aSource - The source from which this event originated.public ActionPayloadMetaDataEventBuilderImpl(String aAlias, String aGroup, String aChannel, String aUid, Class<?> aPublisherType, Object aSource)
aAlias - The alias property.aGroup - The group property.aChannel - The channel property.aUid - The UID (Universal-ID) property.aPublisherType - The type of the event publisher.aSource - The source from which this event originated.public ActionPayloadMetaDataEventBuilderImpl(EventMetaData aEventMetaData, Object aSource)
aEventMetaData - The Meta-Data to by supplied by the event.aSource - The source from which this event originated.public ActionPayloadMetaDataEventBuilderImpl(Object aSource)
aSource - The source from which this event originated.public ActionPayloadMetaDataEventBuilderImpl(P aPayload, EventMetaData aEventMetaData, Object aSource)
aPayload - The payload to be carried by the event.aEventMetaData - The Meta-Data to by supplied by the event.aSource - The source from which this event originated.public void setPublisherType(Class<?> aPublisherType)
setPublisherType in interface EventMetaData.EventMetaDataBuilderaPublisherType - The type of the publisher who published the
event.public void setUniversalId(String aUid)
setUniversalId in interface org.refcodes.mixin.UniversalIdAccessor.UniversalIdMutatorpublic void setAlias(String aAlias)
setAlias in interface org.refcodes.mixin.AliasAccessor.AliasMutatorpublic void setGroup(String aGroup)
setGroup in interface org.refcodes.mixin.GroupAccessor.GroupMutatorpublic void setChannel(String aChannel)
setChannel in interface org.refcodes.mixin.ChannelAccessor.ChannelMutatorpublic void setMetaData(EventMetaData aMetaData)
setMetaData in interface org.refcodes.mixin.MetaDataAccessor.MetaDataMutator<P>public EventMetaData.EventMetaDataBuilder getMetaData()
getMetaData in interface org.refcodes.mixin.MetaDataAccessor<P>getMetaData in class AbstractActionMetaDataEvent<Enum<?>,EventMetaData,Object>Copyright © 2018. All rights reserved.