Package org.refcodes.observer
Class ActionPayloadMetaDataEventImpl<P>
- java.lang.Object
-
- org.refcodes.observer.AbstractEvent<SRC>
-
- org.refcodes.observer.AbstractActionEvent<A,SRC>
-
- org.refcodes.observer.AbstractActionMetaDataEvent<A,EM,SRC>
-
- org.refcodes.observer.AbstractActionPayloadMetaDataEvent<Enum<?>,P,org.refcodes.mixin.EventMetaData,Object>
-
- org.refcodes.observer.ActionPayloadMetaDataEventImpl<P>
-
- Type Parameters:
P- The type of the payload to be carried.
- All Implemented Interfaces:
org.refcodes.mixin.ActionAccessor<P>,org.refcodes.mixin.MetaDataAccessor<P>,org.refcodes.mixin.PayloadAccessor<P>,org.refcodes.mixin.SourceAccessor<P>,ActionEvent,ActionMetaDataEvent,ActionPayloadEvent<P>,ActionPayloadMetaDataEvent<P>,Event,GenericActionEvent<Enum<?>,org.refcodes.mixin.EventMetaData>,GenericActionMetaDataEvent<Enum<?>,org.refcodes.mixin.EventMetaData,Object>,GenericActionPayloadEvent<A,P,SRC>,GenericActionPayloadMetaDataEvent<Enum<?>,P,org.refcodes.mixin.EventMetaData,Object>,GenericEvent<P>,GenericMetaDataEvent<Enum<?>,org.refcodes.mixin.EventMetaData>,GenericPayloadEvent<P,SRC>,GenericPayloadMetaDataEvent<P,org.refcodes.mixin.EventMetaData,Object>,MetaDataEvent,PayloadEvent<P>,PayloadMetaDataEvent<P>
public class ActionPayloadMetaDataEventImpl<P> extends AbstractActionPayloadMetaDataEvent<Enum<?>,P,org.refcodes.mixin.EventMetaData,Object> implements ActionPayloadMetaDataEvent<P>
Basic implementation of theAbstractActionPayloadMetaDataEvent.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from class org.refcodes.observer.AbstractActionMetaDataEvent
AbstractActionMetaDataEvent.AbstractActionMetaDataEventBuilder<A,EM extends org.refcodes.mixin.EventMetaData,SRC,B extends GenericActionMetaDataEvent.GenericActionMetaDataEventBuilder<A,EM,SRC,B>>
-
Nested classes/interfaces inherited from class org.refcodes.observer.AbstractActionPayloadMetaDataEvent
AbstractActionPayloadMetaDataEvent.AbstractActionPayloadMetaDataEventBuilder<A,P,EM extends org.refcodes.mixin.EventMetaData,SRC,B extends GenericActionPayloadMetaDataEvent.GenericActionPayloadMetaDataEventBuilder<A,P,EM,SRC,B>>
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.ActionAccessor
org.refcodes.mixin.ActionAccessor.ActionBuilder<A extends Object,B extends org.refcodes.mixin.ActionAccessor.ActionBuilder<A,B>>, org.refcodes.mixin.ActionAccessor.ActionMutator<A extends Object>, org.refcodes.mixin.ActionAccessor.ActionProperty<A extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.observer.ActionMetaDataEvent
ActionMetaDataEvent.ActionMetaDataEventBuilder
-
Nested classes/interfaces inherited from interface org.refcodes.observer.ActionPayloadMetaDataEvent
ActionPayloadMetaDataEvent.ActionPayloadMetaDataEventBuilder<P>
-
Nested classes/interfaces inherited from interface org.refcodes.observer.GenericActionMetaDataEvent
GenericActionMetaDataEvent.GenericActionMetaDataEventBuilder<A,EM extends org.refcodes.mixin.EventMetaData,SRC,B extends GenericActionMetaDataEvent.GenericActionMetaDataEventBuilder<A,EM,SRC,B>>
-
Nested classes/interfaces inherited from interface org.refcodes.observer.GenericActionPayloadMetaDataEvent
GenericActionPayloadMetaDataEvent.GenericActionPayloadMetaDataEventBuilder<A,P,EM extends org.refcodes.mixin.EventMetaData,SRC,B extends GenericActionPayloadMetaDataEvent.GenericActionPayloadMetaDataEventBuilder<A,P,EM,SRC,B>>
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.MetaDataAccessor
org.refcodes.mixin.MetaDataAccessor.MetaDataBuilder<MD extends Object,B extends org.refcodes.mixin.MetaDataAccessor.MetaDataBuilder<MD,B>>, org.refcodes.mixin.MetaDataAccessor.MetaDataMutator<MD extends Object>, org.refcodes.mixin.MetaDataAccessor.MetaDataProperty<MD extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.PayloadAccessor
org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P extends Object,B extends org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P,B>>, org.refcodes.mixin.PayloadAccessor.PayloadMutator<P extends Object>, org.refcodes.mixin.PayloadAccessor.PayloadProperty<P extends Object>
-
-
Field Summary
-
Fields inherited from class org.refcodes.observer.AbstractActionEvent
_action
-
Fields inherited from class org.refcodes.observer.AbstractActionMetaDataEvent
_eventMetaData
-
-
Constructor Summary
Constructors Constructor Description ActionPayloadMetaDataEventImpl(Enum<?> aAction, Class<?> aPublisherType, Object aSource)Constructs an event with predefined values for the according properties retrieved from the caller's class.ActionPayloadMetaDataEventImpl(Enum<?> aAction, Object aSource)Constructs an event with the given Meta-Data.ActionPayloadMetaDataEventImpl(Enum<?> aAction, String aChannel, Object aSource)Constructs an event with predefined values for the according properties retrieved from the caller's class.ActionPayloadMetaDataEventImpl(Enum<?> aAction, String aAlias, String aGroup, String aChannel, String aUid, Class<?> aPublisherType, Object aSource)Constructs an event with the given values for the according properties.ActionPayloadMetaDataEventImpl(Enum<?> aAction, org.refcodes.mixin.EventMetaData aEventMetaData, Object aSource)Constructs an event with the given Meta-Data.ActionPayloadMetaDataEventImpl(Enum<?> aAction, P aPayload, Object aSource)Constructs an event with the given Meta-Data.ActionPayloadMetaDataEventImpl(Enum<?> aAction, P aPayload, org.refcodes.mixin.EventMetaData aEventMetaData, Object aSource)Constructs an event with the given Meta-Data.ActionPayloadMetaDataEventImpl(P aPayload, Object aSource)Constructs an event with the given Meta-Data.ActionPayloadMetaDataEventImpl(P aPayload, org.refcodes.mixin.EventMetaData aEventMetaData, Object aSource)Constructs an event with the given Meta-Data.
-
Method Summary
-
Methods inherited from class org.refcodes.observer.AbstractActionEvent
getAction
-
Methods inherited from class org.refcodes.observer.AbstractActionMetaDataEvent
getMetaData, toString
-
Methods inherited from class org.refcodes.observer.AbstractActionPayloadMetaDataEvent
getPayload
-
Methods inherited from class org.refcodes.observer.AbstractEvent
getSource
-
-
-
-
Constructor Detail
-
ActionPayloadMetaDataEventImpl
public ActionPayloadMetaDataEventImpl(Enum<?> aAction, Class<?> aPublisherType, Object aSource)
Constructs an event with predefined values for the according properties retrieved from the caller's class.- Parameters:
aAction- The action which this represents.aPublisherType- The type of the event publisher.aSource- The source from which this event originated.
-
ActionPayloadMetaDataEventImpl
public ActionPayloadMetaDataEventImpl(Enum<?> aAction, String aChannel, Object aSource)
Constructs an event with predefined values for the according properties retrieved from the caller's class.- Parameters:
aAction- The action which this represents.aChannel- The channel name on which the event is receivable.aSource- The source from which this event originated.
-
ActionPayloadMetaDataEventImpl
public ActionPayloadMetaDataEventImpl(Enum<?> aAction, String aAlias, String aGroup, String aChannel, String aUid, Class<?> aPublisherType, Object aSource)
Constructs an event with the given values for the according properties.- Parameters:
aAction- The action which this represents.aAlias- The alias property.aGroup- The group property.aChannel- The channel property.aUid- The UID (Universal-ID) property.aPublisherType- The type of the event publisher.aSource- The source from which this event originated.
-
ActionPayloadMetaDataEventImpl
public ActionPayloadMetaDataEventImpl(Enum<?> aAction, org.refcodes.mixin.EventMetaData aEventMetaData, Object aSource)
Constructs an event with the given Meta-Data.- Parameters:
aAction- The action which this represents.aEventMetaData- The Meta-Data to by supplied by the event.aSource- The source from which this event originated.
-
ActionPayloadMetaDataEventImpl
public ActionPayloadMetaDataEventImpl(Enum<?> aAction, Object aSource)
Constructs an event with the given Meta-Data.- Parameters:
aAction- The action which this represents.aSource- The source from which this event originated.
-
ActionPayloadMetaDataEventImpl
public ActionPayloadMetaDataEventImpl(Enum<?> aAction, P aPayload, org.refcodes.mixin.EventMetaData aEventMetaData, Object aSource)
Constructs an event with the given Meta-Data.- Parameters:
aAction- The action which the event represents.aPayload- The payload to be carried by the event.aEventMetaData- The Meta-Data to by supplied by the event.aSource- The source from which this event originated.
-
ActionPayloadMetaDataEventImpl
public ActionPayloadMetaDataEventImpl(Enum<?> aAction, P aPayload, Object aSource)
Constructs an event with the given Meta-Data.- Parameters:
aAction- The action which the event represents.aPayload- The payload to be carried by the event.aSource- The source from which this event originated.
-
ActionPayloadMetaDataEventImpl
public ActionPayloadMetaDataEventImpl(P aPayload, org.refcodes.mixin.EventMetaData aEventMetaData, Object aSource)
Constructs an event with the given Meta-Data.- Parameters:
aPayload- The payload to be carried by the event.aEventMetaData- The Meta-Data to by supplied by the event.aSource- The source from which this event originated.
-
-