org.refcodes.mixin.ActionAccessor<Enum<?>>, org.refcodes.mixin.MetaDataAccessor<Enum<?>>, org.refcodes.mixin.SourceAccessor<Enum<?>>, ActionEvent, Event, GenericActionEvent<Enum<?>,org.refcodes.mixin.EventMetaData>, GenericActionMetaDataEvent<Enum<?>,org.refcodes.mixin.EventMetaData,Object>, GenericEvent<Enum<?>>, GenericMetaDataEvent<Enum<?>,org.refcodes.mixin.EventMetaData>, MetaDataActionEvent, MetaDataEventpublic class MetaDataActionEventImpl extends AbstractMetaDataActionEvent<Enum<?>,org.refcodes.mixin.EventMetaData,Object> implements MetaDataActionEvent
AbstractMetaDataActionEvent.AbstractActionMetaDataEventBuilder<A,EM extends org.refcodes.mixin.EventMetaData,SRC,B extends GenericActionMetaDataEvent.GenericActionMetaDataEventBuilder<A,EM,SRC,B>>org.refcodes.mixin.ActionAccessor.ActionBuilder<A extends Object,B extends org.refcodes.mixin.ActionAccessor.ActionBuilder<A,B>>, org.refcodes.mixin.ActionAccessor.ActionMutator<A extends Object>, org.refcodes.mixin.ActionAccessor.ActionProperty<A extends Object>GenericActionMetaDataEvent.GenericActionMetaDataEventBuilder<A,EM extends org.refcodes.mixin.EventMetaData,SRC,B extends GenericActionMetaDataEvent.GenericActionMetaDataEventBuilder<A,EM,SRC,B>>org.refcodes.mixin.MetaDataAccessor.MetaDataBuilder<MD extends Object,B extends org.refcodes.mixin.MetaDataAccessor.MetaDataBuilder<MD,B>>, org.refcodes.mixin.MetaDataAccessor.MetaDataMutator<MD extends Object>, org.refcodes.mixin.MetaDataAccessor.MetaDataProperty<MD extends Object>MetaDataActionEvent.ActionMetaDataEventBuilder_action_eventMetaData| Constructor | Description |
|---|---|
MetaDataActionEventImpl(Class<?> aPublisherType,
Object aSource) |
Constructs an event with the according properties.
|
MetaDataActionEventImpl(Enum<?> aAction,
Class<?> aPublisherType,
Object aSource) |
Constructs an event with the according properties.
|
MetaDataActionEventImpl(Enum<?> aAction,
Object aSource) |
Constructs an event with the given Meta-Data.
|
MetaDataActionEventImpl(Enum<?> aAction,
String aChannel,
Object aSource) |
Constructs an event with the according properties.
|
MetaDataActionEventImpl(Enum<?> aAction,
String aAlias,
String aGroup,
String aChannel,
String aUid,
Class<?> aPublisherType,
Object aSource) |
Constructs an event with the given values for the according properties.
|
MetaDataActionEventImpl(Enum<?> aAction,
org.refcodes.mixin.EventMetaData aEventMetaData,
Object aSource) |
Constructs an event with the given Meta-Data.
|
MetaDataActionEventImpl(Object aSource) |
Constructs an event with the given Meta-Data.
|
MetaDataActionEventImpl(String aChannel,
Object aSource) |
Constructs an event with the according properties.
|
MetaDataActionEventImpl(String aAlias,
String aGroup,
String aChannel,
String aUid,
Class<?> aPublisherType,
Object aSource) |
Constructs an event with the given values for the according properties.
|
MetaDataActionEventImpl(org.refcodes.mixin.EventMetaData aEventMetaData,
Object aSource) |
Constructs an event with the given Meta-Data.
|
getActiongetSourcegetMetaData, toStringpublic MetaDataActionEventImpl(Class<?> aPublisherType, Object aSource)
aPublisherType - The type of the event publisher.aSource - The source from which this event originated.public MetaDataActionEventImpl(String aChannel, Object aSource)
aChannel - The channel name on which the event is receivable.aSource - The source from which this event originated.public MetaDataActionEventImpl(String aAlias, String aGroup, String aChannel, String aUid, Class<?> aPublisherType, Object aSource)
aAlias - The alias property.aGroup - The group property.aChannel - The channel property.aUid - The UID (Universal-TID) property.aPublisherType - The type of the event publisher.aSource - The source from which this event originated.public MetaDataActionEventImpl(Enum<?> aAction, Class<?> aPublisherType, Object aSource)
aAction - The action which this represents.aPublisherType - The type of the event publisher.aSource - The source from which this event originated.public MetaDataActionEventImpl(Enum<?> aAction, String aChannel, Object aSource)
aAction - The action which this represents.aChannel - The channel name on which the event is receivable.aSource - The source from which this event originated.public MetaDataActionEventImpl(Enum<?> aAction, String aAlias, String aGroup, String aChannel, String aUid, Class<?> aPublisherType, Object aSource)
aAction - The action which this represents.aAlias - The alias property.aGroup - The group property.aChannel - The channel property.aUid - The UID (Universal-TID) property.aPublisherType - The type of the event publisher.aSource - The source from which this event originated.public MetaDataActionEventImpl(org.refcodes.mixin.EventMetaData aEventMetaData,
Object aSource)
aEventMetaData - The Meta-Data to by supplied by the event.aSource - The source from which this event originated.public MetaDataActionEventImpl(Enum<?> aAction, org.refcodes.mixin.EventMetaData aEventMetaData, Object aSource)
aAction - The action which this represents.aEventMetaData - The Meta-Data to by supplied by the event.aSource - The source from which this event originated.public MetaDataActionEventImpl(Enum<?> aAction, Object aSource)
aAction - The action which this represents.aSource - The source from which this event originated.public MetaDataActionEventImpl(Object aSource)
aSource - The source from which this event originated.Copyright © 2021. All rights reserved.