E - the element typeObserverDescriptor<E,O,EM>ObserverDescriptorImpl@FunctionalInterface public interface Observer<E extends GenericEvent<?>>
| Modifier and Type | Method | Description |
|---|---|---|
void |
onEvent(E aEvent) |
The listener implementing this interface is notified of an event via this
method.
|
void onEvent(E aEvent)
aEvent - aEvent The event to be pushed from the publisher to the
subscriber.Copyright © 2021. All rights reserved.