P - The type of the payload to be carried.org.refcodes.mixin.ActionAccessor<P>, org.refcodes.mixin.MetaDataAccessor<P>, org.refcodes.mixin.PayloadAccessor<P>, org.refcodes.mixin.SourceAccessor<P>, ActionEvent, Event, GenericActionEvent<Enum<?>,org.refcodes.mixin.EventMetaData>, GenericActionMetaDataEvent<Enum<?>,org.refcodes.mixin.EventMetaData,Object>, GenericActionPayloadEvent<A,P,SRC>, GenericActionPayloadMetaDataEvent<Enum<?>,P,org.refcodes.mixin.EventMetaData,Object>, GenericEvent<P>, GenericMetaDataEvent<Enum<?>,org.refcodes.mixin.EventMetaData>, GenericPayloadEvent<P,SRC>, GenericPayloadMetaDataEvent<P,org.refcodes.mixin.EventMetaData,Object>, MetaDataActionEvent, MetaDataEvent, PayloadActionEvent<P>, PayloadEvent<P>, PayloadMetaDataActionEvent<P>, PayloadMetaDataEvent<P>public class PayloadMetaDataActionEventImpl<P> extends AbstractPayloadMetaDataActionEvent<Enum<?>,P,org.refcodes.mixin.EventMetaData,Object> implements PayloadMetaDataActionEvent<P>
AbstractPayloadMetaDataActionEvent.AbstractMetaDataActionEvent.AbstractActionMetaDataEventBuilder<A,EM extends org.refcodes.mixin.EventMetaData,SRC,B extends GenericActionMetaDataEvent.GenericActionMetaDataEventBuilder<A,EM,SRC,B>>AbstractPayloadMetaDataActionEvent.AbstractActionPayloadMetaDataEventBuilder<A,P,EM extends org.refcodes.mixin.EventMetaData,SRC,B extends GenericActionPayloadMetaDataEvent.GenericActionPayloadMetaDataEventBuilder<A,P,EM,SRC,B>>org.refcodes.mixin.ActionAccessor.ActionBuilder<A extends Object,B extends org.refcodes.mixin.ActionAccessor.ActionBuilder<A,B>>, org.refcodes.mixin.ActionAccessor.ActionMutator<A extends Object>, org.refcodes.mixin.ActionAccessor.ActionProperty<A extends Object>GenericActionMetaDataEvent.GenericActionMetaDataEventBuilder<A,EM extends org.refcodes.mixin.EventMetaData,SRC,B extends GenericActionMetaDataEvent.GenericActionMetaDataEventBuilder<A,EM,SRC,B>>GenericActionPayloadMetaDataEvent.GenericActionPayloadMetaDataEventBuilder<A,P,EM extends org.refcodes.mixin.EventMetaData,SRC,B extends GenericActionPayloadMetaDataEvent.GenericActionPayloadMetaDataEventBuilder<A,P,EM,SRC,B>>org.refcodes.mixin.MetaDataAccessor.MetaDataBuilder<MD extends Object,B extends org.refcodes.mixin.MetaDataAccessor.MetaDataBuilder<MD,B>>, org.refcodes.mixin.MetaDataAccessor.MetaDataMutator<MD extends Object>, org.refcodes.mixin.MetaDataAccessor.MetaDataProperty<MD extends Object>MetaDataActionEvent.ActionMetaDataEventBuilderorg.refcodes.mixin.PayloadAccessor.PayloadBuilder<P extends Object,B extends org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P,B>>, org.refcodes.mixin.PayloadAccessor.PayloadMutator<P extends Object>, org.refcodes.mixin.PayloadAccessor.PayloadProperty<P extends Object>PayloadMetaDataActionEvent.ActionPayloadMetaDataEventBuilder<P>_action_eventMetaData| Constructor | Description |
|---|---|
PayloadMetaDataActionEventImpl(Enum<?> aAction,
Class<?> aPublisherType,
Object aSource) |
Constructs an event with predefined values for the according properties
retrieved from the caller's class.
|
PayloadMetaDataActionEventImpl(Enum<?> aAction,
Object aSource) |
Constructs an event with the given Meta-Data.
|
PayloadMetaDataActionEventImpl(Enum<?> aAction,
String aChannel,
Object aSource) |
Constructs an event with predefined values for the according properties
retrieved from the caller's class.
|
PayloadMetaDataActionEventImpl(Enum<?> aAction,
String aAlias,
String aGroup,
String aChannel,
String aUid,
Class<?> aPublisherType,
Object aSource) |
Constructs an event with the given values for the according properties.
|
PayloadMetaDataActionEventImpl(Enum<?> aAction,
org.refcodes.mixin.EventMetaData aEventMetaData,
Object aSource) |
Constructs an event with the given Meta-Data.
|
PayloadMetaDataActionEventImpl(Enum<?> aAction,
P aPayload,
Object aSource) |
Constructs an event with the given Meta-Data.
|
PayloadMetaDataActionEventImpl(Enum<?> aAction,
P aPayload,
org.refcodes.mixin.EventMetaData aEventMetaData,
Object aSource) |
Constructs an event with the given Meta-Data.
|
PayloadMetaDataActionEventImpl(P aPayload,
Object aSource) |
Constructs an event with the given Meta-Data.
|
PayloadMetaDataActionEventImpl(P aPayload,
org.refcodes.mixin.EventMetaData aEventMetaData,
Object aSource) |
Constructs an event with the given Meta-Data.
|
getActiongetSourcegetMetaData, toStringgetPayloadpublic PayloadMetaDataActionEventImpl(Enum<?> aAction, Class<?> aPublisherType, Object aSource)
aAction - The action which this represents.aPublisherType - The type of the event publisher.aSource - The source from which this event originated.public PayloadMetaDataActionEventImpl(Enum<?> aAction, String aChannel, Object aSource)
aAction - The action which this represents.aChannel - The channel name on which the event is receivable.aSource - The source from which this event originated.public PayloadMetaDataActionEventImpl(Enum<?> aAction, String aAlias, String aGroup, String aChannel, String aUid, Class<?> aPublisherType, Object aSource)
aAction - The action which this represents.aAlias - The alias property.aGroup - The group property.aChannel - The channel property.aUid - The UID (Universal-TID) property.aPublisherType - The type of the event publisher.aSource - The source from which this event originated.public PayloadMetaDataActionEventImpl(Enum<?> aAction, org.refcodes.mixin.EventMetaData aEventMetaData, Object aSource)
aAction - The action which this represents.aEventMetaData - The Meta-Data to by supplied by the event.aSource - The source from which this event originated.public PayloadMetaDataActionEventImpl(Enum<?> aAction, Object aSource)
aAction - The action which this represents.aSource - The source from which this event originated.public PayloadMetaDataActionEventImpl(Enum<?> aAction, P aPayload, org.refcodes.mixin.EventMetaData aEventMetaData, Object aSource)
aAction - The action which the event represents.aPayload - The payload to be carried by the event.aEventMetaData - The Meta-Data to by supplied by the event.aSource - The source from which this event originated.public PayloadMetaDataActionEventImpl(Enum<?> aAction, P aPayload, Object aSource)
aAction - The action which the event represents.aPayload - The payload to be carried by the event.aSource - The source from which this event originated.public PayloadMetaDataActionEventImpl(P aPayload, org.refcodes.mixin.EventMetaData aEventMetaData, Object aSource)
aPayload - The payload to be carried by the event.aEventMetaData - The Meta-Data to by supplied by the event.aSource - The source from which this event originated.Copyright © 2021. All rights reserved.