| Modifier and Type | Interface | Description |
|---|---|---|
interface |
MetaDataEventMatcher<E extends GenericMetaDataEvent<?,?>> |
This interface typifies the
Matcher interface for the usage with
GenericMetaDataEvent instances. |
| Modifier and Type | Interface | Description |
|---|---|---|
interface |
GenericActionMetaDataEvent<A,EM extends org.refcodes.mixin.EventMetaData,SRC> |
An
GenericActionMetaDataEvent provides Meta-Data describing the
GenericActionEvent in more detail and a source being the origin of
the GenericActionMetaDataEvent. |
static interface |
GenericActionMetaDataEvent.GenericActionMetaDataEventBuilder<A,EM extends org.refcodes.mixin.EventMetaData,SRC,B extends GenericActionMetaDataEvent.GenericActionMetaDataEventBuilder<A,EM,SRC,B>> |
Builder extension for the
GenericActionMetaDataEvent type. |
interface |
GenericActionPayloadMetaDataEvent<A,P,EM extends org.refcodes.mixin.EventMetaData,SRC> |
An
GenericActionPayloadMetaDataEvent provides Meta-Data describing
the GenericActionPayloadMetaDataEvent in more detail and a payload as
well as an action. |
static interface |
GenericActionPayloadMetaDataEvent.GenericActionPayloadMetaDataEventBuilder<A,P,EM extends org.refcodes.mixin.EventMetaData,SRC,B extends GenericActionPayloadMetaDataEvent.GenericActionPayloadMetaDataEventBuilder<A,P,EM,SRC,B>> |
Builder extension for the
GenericActionPayloadMetaDataEvent type. |
interface |
GenericPayloadMetaDataEvent<P,EM extends org.refcodes.mixin.EventMetaData,SRC> |
An
GenericPayloadMetaDataEvent provides Meta-Data describing the
GenericPayloadMetaDataEvent in more detail and a payload. |
interface |
MetaDataActionEvent |
An
MetaDataActionEvent is published by an Observable and is
consumed by zero to many Observer instances. |
static interface |
MetaDataActionEvent.ActionMetaDataEventBuilder |
Builder for the
MetaDataActionEvent. |
interface |
MetaDataEvent |
|
interface |
PayloadMetaDataActionEvent<P> |
An
PayloadMetaDataActionEvent provides Meta-Data describing the
PayloadMetaDataActionEvent in more detail and a payload as well as an
action. |
static interface |
PayloadMetaDataActionEvent.ActionPayloadMetaDataEventBuilder<P> |
Builder extension for the
PayloadMetaDataActionEvent type. |
interface |
PayloadMetaDataEvent<P> |
An
PayloadMetaDataEvent provides Meta-Data describing the
GenericPayloadMetaDataEvent in more detail and a payload. |
| Modifier and Type | Method | Description |
|---|---|---|
static <E extends GenericMetaDataEvent<?,?>> |
EventMatcherSugar.and(EventMatcher<E>... aEventMatchers) |
Factory method to create an "AND" matcher for the given matchers.
|
static <E extends GenericMetaDataEvent<?,?>> |
EventMatcherSugar.catchAll() |
Catches all events, no matching is done.
|
static <E extends GenericMetaDataEvent<?,?>> |
EventMatcherSugar.catchNone() |
Catches no event, no matching is done.
|
static <E extends GenericMetaDataEvent<?,?>> |
EventMatcherSugar.groupEqualWith(String aGroup) |
Factory method to create an "EQUAL WITH" matcher for the given group
compared with the group stored in the
EventMetaData. |
static <E extends GenericMetaDataEvent<?,?>> |
EventMatcherSugar.isAssignableFrom(Class<?> aEventType) |
Factory method to create an event matcher by event type.
|
static <E extends GenericMetaDataEvent<?,?>> |
EventMatcherSugar.nameEqualWith(String aAlias) |
Factory method to create an "EQUAL WITH" matcher for the given name
compared with the name stored in the
EventMetaData. |
static <E extends GenericMetaDataEvent<?,?>> |
EventMatcherSugar.or(EventMatcher<E>... aEventMatchers) |
Factory method to create an "OR" matcher for the given matchers.
|
static <E extends GenericMetaDataEvent<?,?>,PT> |
EventMatcherSugar.publisherIsAssignableFrom(Class<? extends PT> aPublisherType) |
Factory method to create an event matcher by event publisher type.
|
static <E extends GenericMetaDataEvent<?,?>> |
EventMatcherSugar.universalIdEqualWith(String aUid) |
Factory method to create an "EQUAL WITH" matcher for the given UID
compared with the UID stored in the
EventMetaData. |
Copyright © 2021. All rights reserved.