| Modifier and Type | Class | Description |
|---|---|---|
class |
ObserverDescriptorImpl<E extends GenericEvent<?>,O extends Observer<E>,EM extends EventMatcher<E>> |
As a descriptor describes something fixed, this class is immutable in the
sense that there are no setters for the attributes.
|
Copyright © 2021. All rights reserved.