All Classes and Interfaces
Class
Description
The
AbstractActionEvent provides a base implementation for an
ActionEvent.The
AbstractEvent provides a base implementation for an
Event.Abstract implementation of an
EventMatcher type.The
AbstractMetaDataActionEvent provides a base implementation for an
MetaDataActionEvent.AbstractMetaDataActionEvent.AbstractMetaDataActionEventBuilder<A,EM extends EventMetaData,SRC,B extends AbstractMetaDataActionEvent.AbstractMetaDataActionEventBuilder<A,EM,SRC,B>>
Implementation of the
MetaDataAccessor.MetaDataBuilder interface for easily
creating MetaDataActionEvent instances.The
AbstractMetaDataEvent provides a base implementation for an
MetaDataEvent.This abstract class provides functionality to implement default refcodes
Observable behavior.Matches the given action with the action stored in an event's meta data
(ACTION EQUAL WITH).
An
ActionEvent extends the Event and provides
additional means to provide an action via ActionAccessor.getAction() being of a
generic type.Matches the given alias with the alias stored in an event's meta data (ALIAS
EQUAL WITH).
Catches all events, no matching is done (CATCH ALL).
Catches no events, no matching is done (CATCH NONE).
Matches the given channel with the channel stored in an event's meta data
(CHANNEL EQUAL WITH).
This interface typifies the
Matcher interface for the usage with
ActionEvent instances.Declarative syntactic sugar which may be statically imported in order to
allow declarative definitions for the
EventMatcher elements.The Meta-Data describes the event which a publisher posts via the event bus
to an event subscriber's event listener.
The
EventMetaDataBuilder is the builder class counterpart of the
EventMetaData class.Matches the given group with the group stored in an event's meta data (GROUP
EQUAL WITH).
An
MetaDataActionEvent provides Meta-Data describing the
ActionEvent in more detail and a source being the origin of
the MetaDataActionEvent.MetaDataActionEventBuilder<A,EM extends EventMetaData,SRC,B extends MetaDataActionEventBuilder<A,EM,SRC,B>>
Builder extension for the
MetaDataActionEvent type.An
MetaDataEvent provides Meta-Data describing the
ActionEvent in more detail and a source being the origin of
the MetaDataEvent.Builder extension for the
MetaDataActionEvent type.This interface typifies the
Matcher interface for the usage with
MetaDataEvent instances.The
Observable interface can be implemented by any class which can be
observed by Observer instances (proposal) or any listener interface
(custom as of your needs).An
ObservableObserver is an observer, observing an observable.The listener of an event subscriber to be fed with events by a event
publisher.
This
ObserverDescriptor describes the Observer, i.e. in some
cases an Observer requires an EventMatcher which determines
which ActionEvent instances to pass to the Observer.Provides methods to manage all subscribed
Observer instances as a
whole and is intended as an extension of the Observable interface.A system publishing
ActionEvent instances (such as an event
bus), may implement this interface.Matches by event publisher type (EVENT PUBLISHER TYPE).
An
SubscribeEvent is published by an Observable when an
observer is being subscribed.Matches the given universal ID with the universal ID stored in an event's
meta data (UNIVERSAL ID EQUAL WITH).
An
UnsubscribeEvent is published by an Observable when an
observer is being unsubscribed.