- Type Parameters:
A- The type of the action stored in the event.SRC- The type of the source in question.
- All Superinterfaces:
org.refcodes.mixin.ActionAccessor<A>,Event<SRC>,org.refcodes.mixin.SourceAccessor<SRC>
- All Known Subinterfaces:
MetaDataActionEvent<A,,EM, SRC> MetaDataActionEventBuilder<A,EM, SRC, B>
- All Known Implementing Classes:
AbstractActionEvent,AbstractMetaDataActionEvent,AbstractMetaDataActionEvent.AbstractMetaDataActionEventBuilder
An
ActionEvent extends the Event and provides
additional means to provide an action via ActionAccessor.getAction() being of a
generic type. The action can be used to easily describe the intend of the
event without sub-classing an ActionEvent enabled
{GenericEvent} class for each intend.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.ActionAccessor
org.refcodes.mixin.ActionAccessor.ActionBuilder<A extends Object,B extends org.refcodes.mixin.ActionAccessor.ActionBuilder<A, B>>, org.refcodes.mixin.ActionAccessor.ActionMutator<A extends Object>, org.refcodes.mixin.ActionAccessor.ActionProperty<A extends Object> -
Method Summary
Methods inherited from interface org.refcodes.mixin.ActionAccessor
getActionMethods inherited from interface org.refcodes.mixin.SourceAccessor
getSource