- Type Parameters:
SRC- The type of the source in question.
- All Superinterfaces:
org.refcodes.mixin.SourceAccessor<SRC>
- All Known Subinterfaces:
ActionEvent<A,,SRC> MetaDataActionEvent<A,,EM, SRC> MetaDataActionEventBuilder<A,,EM, SRC, B> MetaDataEvent<EM,,SRC> MetaDataEventBuilder<A,EM, SRC, B>
- All Known Implementing Classes:
AbstractActionEvent,AbstractEvent,AbstractMetaDataActionEvent,AbstractMetaDataActionEvent.AbstractMetaDataActionEventBuilder,AbstractMetaDataEvent,SubscribeEvent,UnsubscribeEvent
public interface Event<SRC>
extends org.refcodes.mixin.SourceAccessor<SRC>
An
Event is published by an Observable and is consumed
by zero to many Observer instances. The Event object
describes what the Observable is publishing. An Event
provides a source being the origin of the Event.-
Nested Class Summary
-
Method Summary
Methods inherited from interface org.refcodes.mixin.SourceAccessor
getSource