Module org.refcodes.observer
Package org.refcodes.observer
Interface EventMatcher<E extends Event<?>>
- Type Parameters:
E- The matchee type.
- All Superinterfaces:
org.refcodes.mixin.AliasAccessor,org.refcodes.matcher.Matchable<E>,org.refcodes.matcher.Matcher<E>,org.refcodes.schema.Schemable
- All Known Subinterfaces:
MetaDataEventMatcher<E>
- All Known Implementing Classes:
AbstractEventMatcher,ActionEqualWithEventMatcher,AliasEqualWithEventMatcher,CatchAllEventMatcher,CatchNoneEventMatcher,ChannelEqualWithEventMatcher,GroupEqualWithEventMatcher,PublisherTypeOfEventMatcher,UniversalIdEqualWithEventMatcher
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
@FunctionalInterface
public interface EventMatcher<E extends Event<?>>
extends org.refcodes.matcher.Matcher<E>
This interface typifies the
Matcher interface for the usage with
ActionEvent instances. An EventMatcher most commonly uses the
EventMetaData (as defined with the MetaDataEvent) in order to
determine whether an ActionEvent matches EventMetaData
properties or not.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasProperty -
Method Summary
Modifier and TypeMethodDescriptionbooleanisMatching(E aEvent) Tests whether the givenActionEventis matching theMatcher's criteria.Methods inherited from interface org.refcodes.matcher.Matcher
getAlias, toSchema
-
Method Details
-
isMatching
Tests whether the givenActionEventis matching theMatcher's criteria.- Specified by:
isMatchingin interfaceorg.refcodes.matcher.Matchable<E extends Event<?>>- Parameters:
aEvent- TheActionEventused for testing its matchability.- Returns:
- True in case the
ActionEventmatches theMatcher's criteria, else false.
-