java.lang.Object
org.refcodes.observer.EventMetaData
- All Implemented Interfaces:
org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.ChannelAccessor,org.refcodes.mixin.GroupAccessor,org.refcodes.mixin.UniversalIdAccessor,PublisherTypeAccessor
public class EventMetaData
extends Object
implements org.refcodes.mixin.UniversalIdAccessor, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.GroupAccessor, org.refcodes.mixin.ChannelAccessor, PublisherTypeAccessor
The Meta-Data describes the event which a publisher posts via the event bus
to an event subscriber's event listener. The Meta-Data is the criteria most
commonly used by an event matcher in order to identify an loosely coupled
event.
-
Nested Class Summary
Nested ClassesNested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.ChannelAccessor
org.refcodes.mixin.ChannelAccessor.ChannelBuilder<B extends org.refcodes.mixin.ChannelAccessor.ChannelBuilder<B>>, org.refcodes.mixin.ChannelAccessor.ChannelMutator, org.refcodes.mixin.ChannelAccessor.ChannelPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.GroupAccessor
org.refcodes.mixin.GroupAccessor.GroupBuilder<B extends org.refcodes.mixin.GroupAccessor.GroupBuilder<B>>, org.refcodes.mixin.GroupAccessor.GroupMutator, org.refcodes.mixin.GroupAccessor.GroupPropertyNested classes/interfaces inherited from interface org.refcodes.observer.PublisherTypeAccessor
PublisherTypeAccessor.PublisherTypeBuilder<B extends PublisherTypeAccessor.PublisherTypeBuilder<B>>, PublisherTypeAccessor.PublisherTypeMutator, PublisherTypeAccessor.PublisherTypePropertyNested classes/interfaces inherited from interface org.refcodes.mixin.UniversalIdAccessor
org.refcodes.mixin.UniversalIdAccessor.UniversalIdBuilder<B extends org.refcodes.mixin.UniversalIdAccessor.UniversalIdBuilder<B>>, org.refcodes.mixin.UniversalIdAccessor.UniversalIdMutator, org.refcodes.mixin.UniversalIdAccessor.UniversalIdProperty -
Field Summary
Fields -
Constructor Summary
ConstructorsConstructorDescriptionConstructs theEventMetaDatawith no properties set except the Universal-TID.EventMetaData(Class<?> aPublisherType) Constructs theEventMetaDatawith the given properties.EventMetaData(String aChannel) Constructs theEventMetaDatawith the given properties.EventMetaData(String aChannel, Class<?> aPublisherType) Constructs theEventMetaDatawith the given properties.EventMetaData(String aAlias, String aGroup) Constructs theEventMetaDatawith the given properties.EventMetaData(String aAlias, String aGroup, String aChannel) Constructs theEventMetaDatawith the given properties.EventMetaData(String aAlias, String aGroup, String aChannel, Class<?> aPublisherType) Constructs theEventMetaDatawith the given properties.Constructs theEventMetaDatawith the given properties.EventMetaData(EventMetaData aMetaData) Constructs theEventMetaDatawith the properties provided by the givenEventMetaDatainstance. -
Method Summary
Modifier and TypeMethodDescriptionstatic EventMetaData.Builderbuilder()Creates builder to buildEventMetaData.getAlias()getGroup()Class<?>Retrieves the publisher's type property.toString()
-
Field Details
-
_alias
-
_channel
-
_group
-
_uid
-
_publisherType
-
-
Constructor Details
-
EventMetaData
public EventMetaData()Constructs theEventMetaDatawith no properties set except the Universal-TID. -
EventMetaData
Constructs theEventMetaDatawith the given properties.- Parameters:
aPublisherType- The type of the publisher.
-
EventMetaData
Constructs theEventMetaDatawith the properties provided by the givenEventMetaDatainstance.- Parameters:
aMetaData- TheEventMetaDatainstance from which to get the properties.
-
EventMetaData
Constructs theEventMetaDatawith the given properties.- Parameters:
aChannel- The channel for theEventMetaData.
-
EventMetaData
Constructs theEventMetaDatawith the given properties.- Parameters:
aChannel- The channel for theEventMetaData.aPublisherType- The publisher type for theEventMetaData.
-
EventMetaData
Constructs theEventMetaDatawith the given properties.- Parameters:
aAlias- The alias for theEventMetaData.aGroup- The group for theEventMetaData.
-
EventMetaData
Constructs theEventMetaDatawith the given properties.- Parameters:
aAlias- The alias for theEventMetaData.aGroup- The group for theEventMetaData.aChannel- The channel for theEventMetaData.
-
EventMetaData
Constructs theEventMetaDatawith the given properties.- Parameters:
aAlias- The alias for theEventMetaData.aGroup- The group for theEventMetaData.aChannel- The channel for theEventMetaData.aPublisherType- The publisher type for theEventMetaData.
-
EventMetaData
public EventMetaData(String aAlias, String aGroup, String aChannel, String aUid, Class<?> aPublisherType) Constructs theEventMetaDatawith the given properties.- Parameters:
aAlias- The alias for theEventMetaData.aGroup- The group for theEventMetaData.aChannel- The channel for theEventMetaData.aUid- The Universal-TID for theEventMetaData.aPublisherType- The publisher type for theEventMetaData.
-
-
Method Details
-
getAlias
- Specified by:
getAliasin interfaceorg.refcodes.mixin.AliasAccessor
-
getChannel
- Specified by:
getChannelin interfaceorg.refcodes.mixin.ChannelAccessor
-
getGroup
- Specified by:
getGroupin interfaceorg.refcodes.mixin.GroupAccessor
-
getPublisherType
Retrieves the publisher's type property.- Specified by:
getPublisherTypein interfacePublisherTypeAccessor- Returns:
- The publisher's type stored by the property.
-
getUniversalId
- Specified by:
getUniversalIdin interfaceorg.refcodes.mixin.UniversalIdAccessor
-
toString
-
builder
Creates builder to buildEventMetaData.- Returns:
- created builder
-