Interface MetaDataActionEvent<A, EM extends EventMetaData, SRC>
- Type Parameters:
A- The type of the action stored in the event.EM- The type of the EventMetaDataSRC- The type of the source in question.
- All Superinterfaces:
ActionAccessor<A>, ActionEvent<A,SRC>, Event<SRC>, MetaDataAccessor<EM>, MetaDataEvent<EM, SRC>, SourceAccessor<SRC>
- All Known Implementing Classes:
AbstractMetaDataActionEvent
public interface MetaDataActionEvent<A, EM extends EventMetaData, SRC>
extends ActionEvent<A,SRC>, MetaDataEvent<EM,SRC>
An
MetaDataActionEvent provides Meta-Data describing the
ActionEvent in more detail and a source being the origin of the
MetaDataActionEvent.-
Nested Class Summary
Nested classes/interfaces inherited from interface ActionAccessor
ActionAccessor.ActionBuilder<A,B>, ActionAccessor.ActionMutator<A>, ActionAccessor.ActionProperty<A> Nested classes/interfaces inherited from interface MetaDataAccessor
MetaDataAccessor.MetaDataBuilder<MD,B>, MetaDataAccessor.MetaDataMutator<MD>, MetaDataAccessor.MetaDataProperty<MD> Nested classes/interfaces inherited from interface SourceAccessor
SourceAccessor.SourceBuilder<SRC,B>, SourceAccessor.SourceMutator<SRC>, SourceAccessor.SourceProperty<SRC> -
Method Summary
Methods inherited from interface ActionAccessor
getActionMethods inherited from interface MetaDataAccessor
getMetaDataMethods inherited from interface SourceAccessor
getSource