Module org.refcodes.observer
Package org.refcodes.observer
Interface MetaDataEventMatcher<E extends GenericMetaDataEvent<?,?>>
- Type Parameters:
E- The matchee type
- All Superinterfaces:
EventMatcher<E>,org.refcodes.matcher.Matcher<E>
public interface MetaDataEventMatcher<E extends GenericMetaDataEvent<?,?>> extends EventMatcher<E>
This interface typifies the
Matcher interface for the usage with
GenericMetaDataEvent instances. An EventMatcher most commonly
uses the EventMetaData (as defined with the
GenericMetaDataEvent) in order to determine whether an
GenericActionEvent matches EventMetaData properties or not.-
Method Summary
Modifier and Type Method Description booleanisMatching(E aEvent)Tests whether the given event is matching the mathcer's criteria.
-
Method Details
-
isMatching
Tests whether the given event is matching the mathcer's criteria.- Specified by:
isMatchingin interfaceEventMatcher<E extends GenericMetaDataEvent<?,?>>- Specified by:
isMatchingin interfaceorg.refcodes.matcher.Matcher<E extends GenericMetaDataEvent<?,?>>- Parameters:
aEvent- The event used for testing its matchability.- Returns:
- True in case the event matches the matcher's criteria, else false.
-