Module org.refcodes.observer
Package org.refcodes.observer
Interface MetaDataEventMatcher<E extends MetaDataEvent<?,?>>
- Type Parameters:
E- The matchee type
- All Superinterfaces:
org.refcodes.mixin.AliasAccessor,EventMatcher<E>,org.refcodes.matcher.Matchable<E>,org.refcodes.matcher.Matcher<E>,org.refcodes.mixin.Schemable
This interface typifies the
Matcher interface for the usage with
MetaDataEvent instances. An EventMatcher most commonly
uses the EventMetaData (as defined with the
MetaDataEvent) in order to determine whether an
ActionEvent matches EventMetaData properties or not.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasProperty -
Method Summary
Modifier and TypeMethodDescriptionbooleanisMatching(E aEvent) Tests whether the given event is matching the mathcer's criteria.Methods inherited from interface org.refcodes.mixin.AliasAccessor
getAliasMethods inherited from interface org.refcodes.matcher.Matcher
toSchema
-
Method Details
-
isMatching
Tests whether the given event is matching the mathcer's criteria.- Specified by:
isMatchingin interfaceEventMatcher<E extends MetaDataEvent<?,?>> - Specified by:
isMatchingin interfaceorg.refcodes.matcher.Matchable<E extends MetaDataEvent<?,?>> - Parameters:
aEvent- The event used for testing its matchability.- Returns:
- True in case the event matches the matcher's criteria, else false.
-