P - The type of the payload to be carried.org.refcodes.mixin.ActionAccessor<P>, org.refcodes.mixin.MetaDataAccessor<P>, org.refcodes.mixin.PayloadAccessor<P>, org.refcodes.mixin.SourceAccessor<P>, ActionEvent, ActionMetaDataEvent, ActionPayloadEvent<P>, ActionPayloadMetaDataEvent<P>, Event, GenericActionEvent<Enum<?>,EventMetaData>, GenericActionMetaDataEvent<Enum<?>,EventMetaData,Object>, GenericActionPayloadEvent<A,P,SRC>, GenericActionPayloadMetaDataEvent<Enum<?>,P,EventMetaData,Object>, GenericEvent<P>, GenericMetaDataEvent<Enum<?>,EventMetaData>, GenericPayloadEvent<P,SRC>, GenericPayloadMetaDataEvent<P,EventMetaData,Object>, MetaDataEvent, PayloadEvent<P>, PayloadMetaDataEvent<P>public class ActionPayloadMetaDataEventImpl<P> extends AbstractActionPayloadMetaDataEvent<Enum<?>,P,EventMetaData,Object> implements ActionPayloadMetaDataEvent<P>
AbstractActionPayloadMetaDataEvent.AbstractActionMetaDataEvent.AbstractActionMetaDataEventBuilder<A,EM extends EventMetaData,SRC,B extends GenericActionMetaDataEvent.GenericActionMetaDataEventBuilder<A,EM,SRC,B>>AbstractActionPayloadMetaDataEvent.AbstractActionPayloadMetaDataEventBuilder<A,P,EM extends EventMetaData,SRC,B extends GenericActionPayloadMetaDataEvent.GenericActionPayloadMetaDataEventBuilder<A,P,EM,SRC,B>>org.refcodes.mixin.ActionAccessor.ActionBuilder<A extends Object,B extends org.refcodes.mixin.ActionAccessor.ActionBuilder<A,B>>, org.refcodes.mixin.ActionAccessor.ActionMutator<A extends Object>, org.refcodes.mixin.ActionAccessor.ActionProperty<A extends Object>ActionMetaDataEvent.ActionMetaDataEventBuilderActionPayloadMetaDataEvent.ActionPayloadMetaDataEventBuilder<P>GenericActionMetaDataEvent.GenericActionMetaDataEventBuilder<A,EM extends EventMetaData,SRC,B extends GenericActionMetaDataEvent.GenericActionMetaDataEventBuilder<A,EM,SRC,B>>GenericActionPayloadMetaDataEvent.GenericActionPayloadMetaDataEventBuilder<A,P,EM extends EventMetaData,SRC,B extends GenericActionPayloadMetaDataEvent.GenericActionPayloadMetaDataEventBuilder<A,P,EM,SRC,B>>org.refcodes.mixin.MetaDataAccessor.MetaDataBuilder<MD extends Object,B extends org.refcodes.mixin.MetaDataAccessor.MetaDataBuilder<MD,B>>, org.refcodes.mixin.MetaDataAccessor.MetaDataMutator<MD extends Object>, org.refcodes.mixin.MetaDataAccessor.MetaDataProperty<MD extends Object>org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P extends Object,B extends org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P,B>>, org.refcodes.mixin.PayloadAccessor.PayloadMutator<P extends Object>, org.refcodes.mixin.PayloadAccessor.PayloadProperty<P extends Object>_action_eventMetaData| Constructor | Description |
|---|---|
ActionPayloadMetaDataEventImpl(Enum<?> aAction,
Class<?> aPublisherType,
Object aSource) |
Constructs an event with predefined values for the according properties
retrieved from the caller's class.
|
ActionPayloadMetaDataEventImpl(Enum<?> aAction,
Object aSource) |
Constructs an event with the given Meta-Data.
|
ActionPayloadMetaDataEventImpl(Enum<?> aAction,
String aChannel,
Object aSource) |
Constructs an event with predefined values for the according properties
retrieved from the caller's class.
|
ActionPayloadMetaDataEventImpl(Enum<?> aAction,
String aAlias,
String aGroup,
String aChannel,
String aUid,
Class<?> aPublisherType,
Object aSource) |
Constructs an event with the given values for the according properties.
|
ActionPayloadMetaDataEventImpl(Enum<?> aAction,
EventMetaData aEventMetaData,
Object aSource) |
Constructs an event with the given Meta-Data.
|
ActionPayloadMetaDataEventImpl(Enum<?> aAction,
P aPayload,
Object aSource) |
Constructs an event with the given Meta-Data.
|
ActionPayloadMetaDataEventImpl(Enum<?> aAction,
P aPayload,
EventMetaData aEventMetaData,
Object aSource) |
Constructs an event with the given Meta-Data.
|
ActionPayloadMetaDataEventImpl(P aPayload,
Object aSource) |
Constructs an event with the given Meta-Data.
|
ActionPayloadMetaDataEventImpl(P aPayload,
EventMetaData aEventMetaData,
Object aSource) |
Constructs an event with the given Meta-Data.
|
getActiongetMetaData, toStringgetPayloadgetSourcepublic ActionPayloadMetaDataEventImpl(Enum<?> aAction, Class<?> aPublisherType, Object aSource)
aAction - The action which this represents.aPublisherType - The type of the event publisher.aSource - The source from which this event originated.public ActionPayloadMetaDataEventImpl(Enum<?> aAction, String aChannel, Object aSource)
aAction - The action which this represents.aChannel - The channel name on which the event is receivable.aSource - The source from which this event originated.public ActionPayloadMetaDataEventImpl(Enum<?> aAction, String aAlias, String aGroup, String aChannel, String aUid, Class<?> aPublisherType, Object aSource)
aAction - The action which this represents.aAlias - The alias property.aGroup - The group property.aChannel - The channel property.aUid - The UID (Universal-ID) property.aPublisherType - The type of the event publisher.aSource - The source from which this event originated.public ActionPayloadMetaDataEventImpl(Enum<?> aAction, EventMetaData aEventMetaData, Object aSource)
aAction - The action which this represents.aEventMetaData - The Meta-Data to by supplied by the event.aSource - The source from which this event originated.public ActionPayloadMetaDataEventImpl(Enum<?> aAction, Object aSource)
aAction - The action which this represents.aSource - The source from which this event originated.public ActionPayloadMetaDataEventImpl(Enum<?> aAction, P aPayload, EventMetaData aEventMetaData, Object aSource)
aAction - The action which the event represents.aPayload - The payload to be carried by the event.aEventMetaData - The Meta-Data to by supplied by the event.aSource - The source from which this event originated.public ActionPayloadMetaDataEventImpl(Enum<?> aAction, P aPayload, Object aSource)
aAction - The action which the event represents.aPayload - The payload to be carried by the event.aSource - The source from which this event originated.public ActionPayloadMetaDataEventImpl(P aPayload, EventMetaData aEventMetaData, Object aSource)
aPayload - The payload to be carried by the event.aEventMetaData - The Meta-Data to by supplied by the event.aSource - The source from which this event originated.Copyright © 2018. All rights reserved.