Uses of Interface
org.refcodes.observer.GenericMetaDataEvent
-
-
Uses of GenericMetaDataEvent in org.refcodes.observer
Classes in org.refcodes.observer with type parameters of type GenericMetaDataEvent Modifier and Type Interface Description interfaceMetaDataEventMatcher<E extends GenericMetaDataEvent<?,?>>This interface typifies theMatcherinterface for the usage withGenericMetaDataEventinstances.Subinterfaces of GenericMetaDataEvent in org.refcodes.observer Modifier and Type Interface Description interfaceActionMetaDataEventAnActionMetaDataEventis published by anObservableand is consumed by zero to manyObserverinstances.static interfaceActionMetaDataEvent.ActionMetaDataEventBuilderBuilder for theActionMetaDataEvent.interfaceActionPayloadMetaDataEvent<P>AnActionPayloadMetaDataEventprovides Meta-Data describing theActionPayloadMetaDataEventin more detail and a payload as well as an action.static interfaceActionPayloadMetaDataEvent.ActionPayloadMetaDataEventBuilder<P>Builder extension for theActionPayloadMetaDataEventtype.interfaceGenericActionMetaDataEvent<A,EM extends org.refcodes.mixin.EventMetaData,SRC>AnGenericActionMetaDataEventprovides Meta-Data describing theGenericActionEventin more detail and a source being the origin of theGenericActionMetaDataEvent.static interfaceGenericActionMetaDataEvent.GenericActionMetaDataEventBuilder<A,EM extends org.refcodes.mixin.EventMetaData,SRC,B extends GenericActionMetaDataEvent.GenericActionMetaDataEventBuilder<A,EM,SRC,B>>Builder extension for theGenericActionMetaDataEventtype.interfaceGenericActionPayloadMetaDataEvent<A,P,EM extends org.refcodes.mixin.EventMetaData,SRC>AnGenericActionPayloadMetaDataEventprovides Meta-Data describing theGenericActionPayloadMetaDataEventin more detail and a payload as well as an action.static interfaceGenericActionPayloadMetaDataEvent.GenericActionPayloadMetaDataEventBuilder<A,P,EM extends org.refcodes.mixin.EventMetaData,SRC,B extends GenericActionPayloadMetaDataEvent.GenericActionPayloadMetaDataEventBuilder<A,P,EM,SRC,B>>Builder extension for theGenericActionPayloadMetaDataEventtype.interfaceGenericPayloadMetaDataEvent<P,EM extends org.refcodes.mixin.EventMetaData,SRC>AnGenericPayloadMetaDataEventprovides Meta-Data describing theGenericPayloadMetaDataEventin more detail and a payload.interfaceMetaDataEventinterfacePayloadMetaDataEvent<P>AnPayloadMetaDataEventprovides Meta-Data describing theGenericPayloadMetaDataEventin more detail and a payload.Methods in org.refcodes.observer with type parameters of type GenericMetaDataEvent Modifier and Type Method Description static <E extends GenericMetaDataEvent<?,?>>
EventMatcher<E>EventMatcherSugar. and(EventMatcher<E>... aEventMatchers)Factory method to create an "AND" matcher for the given matchers.static <E extends GenericMetaDataEvent<?,?>>
EventMatcher<E>EventMatcherSugar. catchAll()Catches all events, no matching is done.static <E extends GenericMetaDataEvent<?,?>>
EventMatcher<E>EventMatcherSugar. catchNone()Catches no event, no matching is done.static <E extends GenericMetaDataEvent<?,?>>
EventMatcher<E>EventMatcherSugar. groupEqualWith(String aGroup)Factory method to create an "EQUAL WITH" matcher for the given group compared with the group stored in theEventMetaData.static <E extends GenericMetaDataEvent<?,?>>
EventMatcher<E>EventMatcherSugar. isAssignableFrom(Class<?> aEventType)Factory method to create an event matcher by event type.static <E extends GenericMetaDataEvent<?,?>>
EventMatcher<E>EventMatcherSugar. nameEqualWith(String aAlias)Factory method to create an "EQUAL WITH" matcher for the given name compared with the name stored in theEventMetaData.static <E extends GenericMetaDataEvent<?,?>>
EventMatcher<E>EventMatcherSugar. or(EventMatcher<E>... aEventMatchers)Factory method to create an "OR" matcher for the given matchers.static <E extends GenericMetaDataEvent<?,?>,PT>
EventMatcher<E>EventMatcherSugar. publisherIsAssignableFrom(Class<? extends PT> aPublisherType)Factory method to create an event matcher by event publisher type.static <E extends GenericMetaDataEvent<?,?>>
EventMatcher<E>EventMatcherSugar. universalIdEqualWith(String aUid)Factory method to create an "EQUAL WITH" matcher for the given UID compared with the UID stored in theEventMetaData.
-